
/* For this example we chose Wave 4 as baseline */ 
set more off
/* 1. CORE data from CAPI and SELF-COMPLETION */
use "N:\STATS\ELSA\STATA\DATA\UKDA_STATA_DATASETS\wave_4_elsa_data_v3.dta", clear

/* 2. MERGE WITH NURSE DATA */
/* Note: Only nurse data at W2 W4 and W6*/
/* Example of selection of variables to merge using the "keepusing" option */
merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\UKDA_STATA_DATASETS\wave_4_nurse_data.dta", ///
keepusing(bmival wstval htval sysval diaval hscrp pulval mapval wtval fglu chol hdl trig ldl hba1c cfib wbc fastask fastelig rtin dheas igf1 mch bloodr)
drop if _merge==2 
drop _merge
/* We want to keep everyone from core data even if they have missing values on 
	nurse visit for the moment */

/* 3. MERGE WITH FINANCIAL DERIVED VARIABLES */
merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\Wave_4_financial_derived_variables.dta", ///
keepusing(nettotw_bu_s totinc_bu_s totinc_bu_s totwq5_bu_s yq5_bu_s)
drop if _merge==2 
drop _merge
tab indsex /* The variable to use for sex */
sum indager /* The variable to use for age */

/* A value of -7 indicate age >=90 collapsed to avoid disclosure */
tab finstat

merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\Wave_4_IFS_derived_variables.dta", keepusing(edqual)
drop if _merge==2 
drop _merge

	
rename indager indagerw4
replace indagerw4=. if indager==99
rename (heeye hefrnd hepap heopcdi heopfgl heopfdi heopfmd heopfca heopndi heopsdi heoptgl heoptdi heoptmd heoptca heopt96 headlco ialreye cfwhteye cfwhmeye) =w4


/* A value of -7 indicate age >=90 collapsed to avoid disclosure */
tab finstat4


sum indagerw4

/********************************/
/****	EMPLOYMENT STATUS	 ****/
/********************************/


tab wpdes, nolab
tab  wpactpw, nolab
tab wpactse 
tab wpactvw 
tab wpactca 
tab wpactlo 
tab  wpacted 
 tab wpact96
 
*****CREATE LABOUR STATUS****.

gen  paidwork = 0
replace paidwork = 1 if wpactpw==1 
gen  selfempl = 0.
replace selfempl= 1 if wpactse==1 

gen  voluwork = 0
replace voluwork= 1 if wpactvw==1 

gen  careddis = 0
replace careddis= 1 if wpactca==1 

gen  lookfami= 0.
replace lookfami= 1 if wpactlo==1 

gen  noneofthese= 0
replace noneofthese= 1 if wpact96==1 


gen attcours=0
replace attcours=1 if wpacted==1 


gen refused =0
replace refused=1 if  wpactpw==-9 |  wpactse==-9 |  wpactvw==-9 |  wpactca==-9 |  wpactlo==-9 |  wpacted==-9 |  wpact96==-9   
tab  refused



gen retiredw4=2
replace retiredw4=1 if wpdes==1 & paidwork==0 & wpever==1 
replace retiredw4=2 if (paidwork==1 | selfempl==1) & (wpdes !=1)
replace retiredw4=1 if (wpdes==96 & paidwork==0)
replace retiredw4=2 if (wpdes==96 & paidwork==1 & wpdes !=1) 
replace retiredw4=3 if (wpdes==5 & paidwork==0 & lookfami==0) 
replace retiredw4=4 if wpdes==4 | (wpaway >= 1 & wpaway <= 3)
replace retiredw4=5 if(wpever==1 & wpdes !=1) 
replace retiredw4=6 if (wpdes==1 | wpdes==6) & (paidwork==0 & lookfami==1) 
replace retiredw4=1 if(noneofthese==1 & wpdes==1) 
replace retiredw4=2 if(noneofthese==1 & wpdes==2)
replace retiredw4=2 if(noneofthese==1 & wpdes==3) 
replace retiredw4=4 if(noneofthese==1 & wpdes==4) 
replace retiredw4=3 if(noneofthese==1 & wpdes==5) 
replace retiredw4=6 if(noneofthese==1 & wpdes==6 & paidwork==0 ) 
replace retiredw4=5 if refused==1| (wpdes >= 85 & wpdes <= 95) 
lab var retiredw4 "Retirement Status"
label define retiredw4 1 "Completely retired" 2 "In paid employment" 3 "Permanently unable to work" 4 "Not currently in paid employment" 5 "Other" 6 "looking after home or family"
lab val retiredw4 retiredw4
tab retiredw4


/********************************/
/****	  EDUCATION	 ****/
/********************************/

*regroup educational categories 
*Education variable - 5 category
tab edqual

gen edu5w4=edqual
recode edu5w4 1=1  2/3=2   4=3  5/6=4    7=5   -9=. -8=. -3=. 
lab define edu5w4 1 "Degree or equivalent" 2 "A-lev/Higher educa. below degree " 3 "O level or other"  4 "CSE/other" 5 "No qualifications" 
lab var edu5w4 "5-group educational category"
lab val edu5w4 edu5w4
tab edu5w4
compress

*Education variable - 3 category
gen edu3w4=edqual
recode edu3w4 1=1  2/6=2    7=3   -9=. -8=. -3=. 
lab define edu3w4  1 "Degree" 2 "Intermediate" 3 "No qualifications" 
lab var edu3w4 "3-group educational category"
lab val edu3w4 edu3w4
tab edu3w4
compress


/********************************/
/****	  MARITAL STATUS	 ****/
/********************************/

tab dimar 
tab dimar, nolab
tab scptr couple 
tab  couple 
tab  couple , nolab
tab scptr
tab scptr, nolab
gen maritalw4=dimar
recode maritalw4 (1=4) (2/4=1) (5/6=2) (7=3) (8/11=1) (-9=-9) (-8=-8)
label define marital 1 "Married" 2 "Separated divorced" 3 "Widowed" 4 "Never married"
lab val maritalw4 marital
tab maritalw4

tab maritalw4 couple 
tab maritalw4 scptr

gen cohabw4=0
replace cohabw4=0 if ((maritalw4==1) & (scptr==1 | couple==2)) 
replace cohabw4=1 if ((maritalw4==1) & (scptr==2 | couple==3)) 
replace cohabw4=2 if ((maritalw4==2) & (scptr==1 | couple==2)) 
 replace cohabw4=3 if ((maritalw4==2) & (scptr==2 | couple==3)) 
replace cohabw4=4 if ((maritalw4==3) & (scptr==1 | couple==2)) 
replace cohabw4=5 if ((maritalw4==3) & (scptr==2 | couple==3)) 
replace cohabw4=6 if ((maritalw4==4) & (scptr==1 | couple==2)) 
replace cohabw4=7 if ((maritalw4==4) & (scptr==2 | couple==3)) 
lab var cohabw4 "cohabiting status"
label define cohab   0"Married cohab" 1"Married not cohab" 2"Sep/divo cohab" 3"Sep/divo not cohab" 4"Widowed cohab" 5"Widowed not cohab" 6"Never married cohab" 7"Never married not cohab"
lab val cohabw4 cohab
tab cohabw4

gen livpartw4= cohabw4 
recode livpartw4 0=0 2=0 4=0 6=0 1=1 3=1 5=1 7=1
lab var  livpartw4 "whether or not living with partner"
label define ynlab 0"yes" 1"no"
lab val livpartw4 ynlab
tab livpartw4


/********************************/
/******   CHRONIC DISEASE  ******/
/********************************/

*** 1. CHD  ***

tab hedawan /* ANGINA Diagnosis fed forward from previous waves */
tab hedawmi /* MYOCARDIAL INFARCTION Diagnosis fed forward from previous waves */
tab hediman /* ANGINA Diagnosis newly reported */
tab hedimmi /* MYOCARDIAL INFARCTION Diagnosis newly reported */
gen chdw4=0 if hedawan==-1 & hedawmi==-1
replace chdw4=1 if hedawan==2 | hedawmi==3 | hediman==1 | hedimmi==1
/* In ELSA missing values are negative : 
-1	= Item not applicable
-9	= Refusal
-8  = Don't Know
-2  = Schedule not applicable
So we replace all negative values by a '.' to indicate missing */
replace chdw4=. if hediman<0 | hedimmi<0

lab var chdw4 "diagnosed CHD"
lab val chdw4 nylab
tab chdw4


rename hedawan hedawanw4
rename hedawmi hedawmiw4
rename hediman hedimanw4
rename hedimmi hedimmiw4

set more off
*** 2. Diabetes ***
tab hedawdi, nolab
tab hedimdi

gen diabetesw4=0 if hedawdi==-1
replace diabetesw4=1 if hedawdi==7 | hedimdi==1
replace diabetesw4=. if hedimdi<0

lab val diabetesw4 nylab
lab var  diabetesw4 "diagnosed diabetes"
tab diabetesw4

*** 3. Depression ***

gen depressw4=0
replace depressw4=1 if hepsyde ==1
replace depressw4=. if hedibps==-1

lab val depressw4 nylab
lab var  depressw4 "diagnosed depression"
tab depressw4

*** 4. Respiratory ***
tab hediblu
tab hedibas

tab hedbwas,nolab
tab hedbwlu,nolab
tab hedbwas hedbwlu

gen fedresp=0 
replace fedresp=1 if hedbwas==2 | hedbwlu==1
tab fedresp

gen respiratw4=0 if fedresp==0
replace respiratw4=1 if fedresp==1 | hediblu==1 | hedibas==1
replace respiratw4=. if  hediblu==. | hedibas==.

lab val respiratw4 nylab
lab var respiratw4 "asthma or lung disease"
tab respiratw4

*** 5. Stroke ***
gen strokew4=0
replace strokew4=1 if hedawst==8 |  hedimst==1
replace strokew4=. if hedimst<0

lab val strokew4 nylab
lab var strokew4 "diagnosed stroke"
tab strokew4


*** 6. Cancer ***
tab hedibca 
tab hedbwca, nolab

gen cancerw4=0 
replace cancerw4=1 if hedibca==1   | hedbwca==5
replace cancerw4=. if hedibca<0
lab val cancerw4 nylab
lab var cancerw4 "diagnosed cancer"
tab cancerw4


*** 7. Arthritis ***
tab hedbwar, nolab
tab hedibar
tab heartoa, nolab 
tab heartra 
tab heartot

gen arthritisw4=0
replace arthritisw4=1 if hedbwar==3 |  hedibar==1
replace arthritisw4=. if  hedibar<0
lab val arthritisw4 nylab
lab var arthritisw4 "diagnosed arthritis"
tab arthritisw4

gen arthw4=0 if arthritisw4==0
replace arthw4=. if arthritisw4==.
replace arthw4=1 if heartoa==1 
replace arthw4=2 if heartra ==1 
replace arthw4=3 if heartot==1 
replace arthw4=4 if heartoa==-8 | heartra ==-8 | heartot==-8

lab var arthw4 "diagnosed arthritis"
label define arthw4lbl 0 "No" 1 "Osteoarthritis" 2 "Rheumatoid arthritis" 3 "other kind of arthritis" 4 "Don't know"
label values arthw4 arthw4lbl
tab arthw4


/********************************/
/****	LIMITING LONG 
		STANDING ILLNESS	 ****/
/********************************/
tab heill
tab helim
tab heill helim
gen limitw4=0
replace limitw4=1 if heill==1 & helim==1
tab limitw4
lab var  limitw4 "limiting longstanding illness"

label define nylab 0"no" 1"yes"
lab val limitw4 nylab


/********************************/
/****	PHYSICAL ACTIVITY	 ****/
/********************************/

sum  heacta heactb heactc
tab heacta
tab heactb
tab heactc
gen w4pavig1=heacta 
recode w4pavig1 1/3= 1 4=0 
lab var w4pavig1 "wave 4 Any vigorous activity"
tab w4pavig1
gen w4pavig2= heacta 
recode w4pavig2 1=1 2/4 = 0 
lab var w4pavig2 "wave 4 Vigorous activity more than once a week"
tab w4pavig2 
gen w4pamod1=heactb
recode w4pamod1 1/3 = 1 4=0 
lab var w4pamod1 "wave 4 Any moderate activity"
tab w4pamod1
gen w4pamod2=heactb
recode  w4pamod2 1=1 2/4=0 
lab var w4pamod2 "wave 4 Moderate activity more than once a week"
tab w4pamod2
tab w4pavig1 


gen w4pacomb1 = 0 if (heacta >2 & heacta<=4) | ( heactb > 2 & heactb<=4)
replace w4pacomb1 = 1 if (heacta >= 1 & heacta <= 2) | (heactb >= 1 & heactb <= 2) 
tab w4pacomb1
lab var w4pacomb1 "wave 4 vigorous/moderate activity at least once per week"

gen w4pased1 = 1 if (heacta==4 & heactb==4 & heactc ==4) 
replace w4pased1 = 0 if (w4pavig1== 1) | w4pamod1==1 | (heactc>= 1 & heactc <=3)
tab w4pased1
lab var w4pased1 "wave 4 Sedentary - No activity in any category"

gen  w4pased2 = 1 if (heacta==4 & heactb ==4)
replace w4pased2 = 0 if (w4pavig1==1) | w4pamod1== 1

tab w4pased2

lab var w4pased2 "wave 4 Sedentary - No vigorous or moderate activity"



gen pa5levelw4 = 0 if (heacta==4 & heactb== 4) 
replace pa5levelw4 = 1 if (heacta== 4 & heactb==2) | (heacta== 4 &  heactb==3) 
replace pa5levelw4 = 2 if (heacta== 4 &  heactb== 1) | (heacta==3 &  heactb==4)
replace pa5levelw4 = 3  if (heacta==2 &  heactb==3) | (heactb== 1 &  heacta==2) | (heactb==1 &  heacta==3) | (heactb==2 &  heacta== 2) | (heactb==2 &  heacta==3) | (heactb==3 &  heacta==3) 
replace pa5levelw4 = 4 if (heacta==1) 
lab var pa5level "wave 4 5 category PA measure"
lab define pa5level 0 "Sedentary" 4 "Active"
lab val pa5levelw4 pa5level
tab pa5levelw4

/********************************/
/****		SMOKING			 ****/
/********************************/
rename heska heskaw4
rename hesmk hesmkw4
set more off
merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\UKDA_STATA_DATASETS\wave_3_elsa_data_v4.dta", keepusing(heska hesmk)
tab _merge
drop _merge
rename heska heskaw3
rename hesmk hesmkw3
merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\UKDA_STATA_DATASETS\wave_2_core_data_v4.dta", keepusing(HESka HeSmk)
tab _merge
drop _merge
rename HESka heskaw2
rename HeSmk hesmkw2
merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\UKDA_STATA_DATASETS\wave_1_core_data_v3.dta", keepusing(heska hesmk)
tab _merge
drop _merge
rename heska heskaw1
rename hesmk hesmkw1

tab heskaw1 hesmkw1, nolab

gen cigstw1=.
replace cigstw1=0 if heskaw1==-1 & (hesmkw1==2 | hesmkw1==-1)
replace cigstw1=1 if heskaw1==2 
replace cigstw1=2 if heskaw1==1
replace cigstw1=0 if heskaw1==2 & hesmkw1==2
replace cigstw1=1 if heskaw1==2 & hesmkw1==1
replace cigstw1=. if  heskaw1==-9 | heskaw1==-8 | hesmkw1==-1
tab cigstw1 heskaw1
tab cigstw1 

tab heskaw2 hesmkw2
tab heskaw2 hesmkw2, nolab


**ever smoked - need combination of qs on ever smoke from w1 and w2 plus qs on smoke now
** people who tell us at wave 1 or wave 2 that have ever smoked
gen eversmkw2 = 1 if hesmkw1==1|hesmkw2==1
**people who said never smoked at wave 1 but smoke at wave 2
replace eversmkw2 = 1 if hesmkw1 ==2 & heskaw2==1
** people who said never smoked at wave 1 and still say not smoking at wave 2
replace eversmkw2 = 0 if hesmkw1==2 & heskaw2==2
**people who did not have an answer at wave 1 and at w2 say never smoked 
replace eversmkw2 = 0 if cigstw1==. & hesmkw2==2
replace eversmkw2 = . if cigstw1==. & (hesmkw2==-4|hesmkw2==-3)

gen cigstw2 = eversmkw2
replace cigstw2 = 2 if heskaw2==1 & eversmkw2 ==1

tab cigstw2
tab cigstw1 cigstw2


tab heskaw3 hesmkw3
tab heskaw3 hesmkw3, nolab

**ever smoked - need combination of qs on ever smoke from previous wave plus qs on smoke now
** people who tell us before or at wave 3 that have ever smoked
gen eversmkw3 = 1 if eversmkw2==1|hesmkw3==1
**people who said never smoked at previous waves but smoke at wave 3
replace eversmkw3 = 1 if eversmkw2 ==0 & heskaw3==1
** people who said never smoked at wave 1 and still say not smoking at wave 3
replace eversmkw3 = 0 if eversmkw2==0 & heskaw3==2
**people who did not have an answer at previous wave and at w3 say never smoked 
replace eversmkw3 = 0 if eversmkw2==. & hesmkw3==2
**people who did not have an answer at previous wave and at w3 say  smoked 
replace eversmkw3 = 1 if eversmkw2==. & hesmkw3==1
replace eversmkw3 = . if eversmkw2==. & hesmkw3==.

gen cigstw3 = eversmkw3
replace cigstw3 = 2 if heskaw3==1 & eversmkw3 ==1
tab cigstw1
tab cigstw2
tab cigstw3
tab cigstw2 cigstw3


tab heskaw4 hesmkw4
tab heskaw4 hesmkw4, nolab

**ever smoked - need combination of qs on ever smoke from previous wave plus qs on smoke now
** people who tell us before or at wave 4 that have ever smoked
gen eversmkw4 = 1 if eversmkw3==1|hesmkw4==1
**people who said never smoked at previous waves but smoke at wave 4
replace eversmkw4 = 1 if eversmkw3 ==0 & heskaw4==1
** people who said never smoked at wave 1 and still say not smoking at wave 4
replace eversmkw4 = 0 if eversmkw3==0 & heskaw4==2
**people who did not have an answer at previous wave and at w4 say never smoked 
replace eversmkw4 = 0 if eversmkw3==. & hesmkw4==2
**people who did not have an answer at previous wave and at w4 say  smoked 
replace eversmkw4 = 1 if eversmkw3==. & hesmkw4==1
replace eversmkw4 = . if eversmkw3==. & hesmkw4==.

gen cigstw4 = eversmkw4
replace cigstw4 = 2 if heskaw4==1 & eversmkw4 ==1
tab cigstw1
tab cigstw2
tab cigstw3
tab cigstw4
tab cigstw3 cigstw4


lab var cigstw1 "Wave 1 Smoking status"
lab var cigstw2 "Wave 2 Smoking status"
lab var cigstw3 "Wave 3 Smoking status"
lab var cigstw4 "Wave 4 Smoking status"

lab define cigstw 0 "Never smoker" 1 "Ex-smoker" 2 "Current smoker"
lab val cigstw1 cigstw
lab val cigstw2 cigstw
lab val cigstw3 cigstw
lab val cigstw4 cigstw

tab cigstw1
tab cigstw2
tab cigstw3
tab cigstw4


/********************************/
/****		  ALCOHOL		 ****/
/********************************/
sum scal7a scako scal7b
tab scal7a
tab scako, nolab
tab scako
tab scal7b
gen alcohw4=scako 
recode alcohw4 3/8=0 2=1 1=1 -9=. -2=. -1=.
label define alcohw4 0"Less than daily" 1"Daily (5/7 days week)"
lab val alcohw4 alcohw4
tab alcohw



/********************************/
/****	  WALKING SPEED 	 ****/
/********************************/
tab mmwlka
tab mmwlkb
tab mmschs
tab mmalone
tab mmhss
tab mmwill
tab mmsaf
tab mmavsp

gen gaitw4 = -99
replace gaitw4=-98 if indager<60 
replace gaitw4=-96 if (gaitw4==-99 & mmschs==-1 & mmalone==-1 & mmhss==-1 & mmwill==-1 & mmsaf==-1 & mmavsp==-1  & mmwala==-1  & mmtrya==-1 & mmwlka==-1 & mmtryb==-1 & mmwlkb==-1)
replace gaitw4=-95 if (gaitw4==-99 & (mmalone==-9 | (mmalone==-1 & mmschs==-9)))
replace gaitw4=-94 if (gaitw4==-99 & mmalone==-8) 
replace gaitw4=-93 if (gaitw4==-99 & mmalone==3) 

replace gaitw4=-92 if (gaitw4==-99 & mmalone==2) 
replace gaitw4=-95 if  (gaitw4==-99 & mmhss==-9) 
replace gaitw4=-94 if (gaitw4==-99 & mmhss==-8) 
replace gaitw4=-91 if (gaitw4==-99 & (mmhss==2 | mmhss==3 | mmhss==4)) 
replace gaitw4=-95 if (gaitw4==-99 & mmwill==-9)
replace gaitw4=-94 if (gaitw4==-99 & mmwill==-8) 
replace gaitw4=-90 if (gaitw4==-99 & mmwill==2)
replace gaitw4=-89 if (gaitw4==-99 & mmsaf==-9) 

replace gaitw4=-88 if (gaitw4==-99 & mmsaf==-8) 
replace gaitw4=-87 if  (gaitw4==-99 & mmsaf==2) 
replace gaitw4=-89 if  (gaitw4==-99 & mmavsp==-9) 
replace gaitw4=-88  if (gaitw4==-99 & mmavsp==-8) 
replace gaitw4=-86 if  (gaitw4==-99 & mmavsp==2) 
replace gaitw4=-95 if  (gaitw4==-99 & mmwala==-9) 
replace gaitw4=-94 if  (gaitw4==-99 & mmwala==-8) 
replace gaitw4=-85 if  (gaitw4==-99 & mmwala==2) 
replace gaitw4=-95 if  (gaitw4==-99 & (mmtrya==-9 | mmtrya==-1 | mmtrya==4 | mmwlka==-9)) 
replace gaitw4=-84  if  (gaitw4==-99 & (mmtrya==2 | mmtrya==3))
replace gaitw4=-82 if  (gaitw4==-99 & ((mmwlka>30 | mmwlka<0.54) & mmwlkb<0)) 
replace gaitw4=-83 if  (gaitw4==-99 & ((mmwlka>30 | mmwlka<0.54) & (mmwlkb>30 | mmwlkb<0.54))) 

replace gaitw4=4.877/(mmwlka+mmwlkb) if  (gaitw4==-99 & (mmwlka<30 & mmwlka>0.54) & (mmwlkb<30 & mmwlkb>0.54))
replace gaitw4 = 2.4384/mmwlka if  (gaitw4==-99 & mmwlka<30 & mmwlka>0.54) 
replace gaitw4 = 2.4384/mmwlkb if  (gaitw4==-99 & mmwlkb<30 & mmwlkb>0.54) 



gen speedindw4 = -1
replace speedindw4 = 1 if  (gaitw4>0  & (mmwlka<30 & mmwlka>0.54) )
replace speedindw4 = 2 if  (gaitw4>0 & (mmwlkb<30 & mmwlkb>0.54) )
replace speedindw4 = 3 if  (gaitw4>0 & (mmwlka<30 & mmwlka>0.54) & (mmwlkb<30 & mmwlkb>0.54))

tab speedindw4

sum gaitw4

gen gaitmisw4=gaitw4 if gaitw4<0
tab gaitmisw4

lab var  gaitw4 "Final wave1 gaitspeed (m/sec)"
lab var speedindw4 "walks used to derive gaitspeed"

label define gaitlab -98 "missing - age<60" -96 "missing NA throughout - reason unknown" -95 "participant refused at some stage" -94 "participant gave DK response" /*
*/ -93 "unable to walk alone" -92 "able to walk but no aid available" -91 "health restriction" -90 "unwilling to do test" -89 "interviewer refused to answer" /*
*/	-88 "interviewer gave DK response" -87 "interviewer felt not safe to do test" -86 "no available space" -85 "felt unsafe" -84 "walk A stopped or not completed" -83 "no speed - both times extreme" /*
*/	-82 "no speed A extreme, B not completed or refused"


label define  speedlab 1 "from walk A only - B extreme etc" 2 "from walk B only - A extreme" 3 "from both walks"

lab val gaitw4 gaitlab 
lab val speedindw4 speedlab
lab val gaitmisw4 gaitlab 

tab gaitw4 if gaitw4<0



	
/********************************/
/****  PHYSICAL FUNCTIONING  ****/
/********************************/
	
	/* ADL COUNT */
sum headldr headlwa headlba headlea headlbe headlwc
tab headldr, nolab
gen adlcntw4=headldr+ headlwa+ headlba +headlea+ headlbe +headlwc
tab adlcntw4
replace adlcntw4=. if adlcntw4<0

	/* IADL COUNT */
sum headlma headlda headlpr headlsh headlte headlco headlme headlho headlmo
tab headlma
gen iadlcntw4=headlma +headlda+headlpr+ headlsh+ headlte+ headlco+ headlme+ headlho +headlmo
tab iadlcntw4
replace iadlcntw4=. if iadlcntw4<0

	/* DIFFICULTIES WITH MOBILITY */
sum hemobwa hemobsi hemobch hemobcs hemobcl hemobst hemobre hemobpu hemobli hemobpi hemob96
tab hemobwa
gen mobilw4=hemobwa +hemobsi+ hemobch+ hemobcs +hemobcl+ hemobst+ hemobre+ hemobpu+ hemobli+ hemobpi 
tab mobilw4
replace mobilw4=. if mobilw4<0
tab mobilw4 hemob96


/*************************************/
/****  DEPRESSIVE SYMPTOMS CES-D  ****/
/*************************************/

sum psceda pscedb pscedc pscedd pscede pscedf pscedg pscedh 


tab	psceda, nolab
tab pscedb
tab pscedc
tab pscedd
tab pscede
tab pscedf, nolab
tab pscedg
tab pscedh

recode	psceda	2=0 -9/-1=.
recode	pscedb	2=0 -9/-1=.
recode pscedc	2=0 -9/-1=.
recode pscedd 2=1 1=0 -9/-1=.
recode pscede 2=0 -9/-1=.
recode pscedf 2=1 1=0 -9/-1=.
recode	pscedg	2=0 -9/-1=.
recode	pscedh	2=0 -9/-1=.




gen totcesdw4=psceda +pscedb +pscedc+ pscedd +pscede +pscedf +pscedg +pscedh
tab totcesdw4

gen depcesdw4=0
replace depcesdw4=1 if totcesdw4>=4
lab var  depcesdw4 "Depressive symptoms CESD"
label define dep 0 "No" 1"Yes"
lab val depcesdw4 dep
tab depcesdw4


/*************************************/
/****  QUALITY OF LIFE CASP  ****/
/*************************************/
sum scqola scqolb scqolc scqold scqole scqolf scqolg scqolh scqoli scqolj scqolk scqoll scqolm scqoln scqolo scqolp scqolq scqolr scqols

gen scqolarc=scqola 
recode scqolarc  (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolbrc=scqolb
recode scqolbrc(1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolfrc=scqolf 
recode scqolfrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolirc=scqoli
recode scqolfrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqoldrc=scqold 
recode scqoldrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolhrc=scqolh
recode scqolhrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)

gen scqolcrc=  scqolc 
recode scqolcrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolcrc (1=0)  (2=1)  (3=2)  (4=3) 

gen scqolerc = scqole
recode scqolerc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolerc (1=0)  (2=1)  (3=2)  (4=3) 

gen scqolgrc = scqolg
recode scqolgrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolgrc (1=0)  (2=1)  (3=2)  (4=3) 

gen scqoljrc  =scqolj
recode scqoljrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqoljrc (1=0)  (2=1)  (3=2)  (4=3) 


gen scqolkrc= scqolk  
recode scqolkrc(1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolkrc (1=0)  (2=1)  (3=2)  (4=3)


gen scqollrc= scqoll 
recode scqollrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqollrc (1=0)  (2=1)  (3=2)  (4=3)


gen scqolmrc=scqolm 
recode scqolmrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolmrc (1=0)  (2=1)  (3=2)  (4=3)

gen  scqolnrc=scqoln  
recode scqolnrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolnrc (1=0)  (2=1)  (3=2)  (4=3)

gen  scqolorc= scqolo 
recode scqolorc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolorc (1=0)  (2=1)  (3=2)  (4=3)


gen  scqolprc =scqolp 
recode scqolprc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolprc (1=0)  (2=1)  (3=2)  (4=3)

gen  scqolqrc = scqolq
recode scqolqrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolqrc (1=0)  (2=1)  (3=2)  (4=3)

 gen scqolrrc =scqolr 
 recode scqolrrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
  recode scqolrrc (1=0)  (2=1)  (3=2)  (4=3)
 
 gen scqolsrc = scqols
 recode scqolsrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
  recode scqolsrc (1=0)  (2=1)  (3=2)  (4=3)
          

gen casp19w4 =scqolarc+ scqolbrc+scqolcrc+ scqoldrc + scqolerc+scqolfrc+ scqolgrc+scqolhrc+ scqolirc+scqoljrc+  scqolkrc + scqollrc + scqolmrc+  scqolnrc + scqolorc + scqolprc + scqolqrc + scqolrrc + scqolsrc 

kdensity casp19w4, normal




**CREATING MEMORY INDEX .
***NB  cflisen and cflisd MUST have -8 coded to 0 in data.

*** Maximum score = 20
tab cflisen
tab cflisd 
recode cflisen  -9/-1=.
recode  cflisd -9/-1=.

gen cfmew4 = cflisen + cflisd  
label var cfmew4 "Memory Index"
tab cfmew4



***CREATING EXECUTIVE FUNCTION INDEX 
***creating new variable cfanig to give scores 1-9
*d/k coded to 0*

tab cfani
recode   cfani   0=0  -9/-1=.  1/7=1  8/12=2  13/15=3  16/17=4  18/19=5  20/21=6  22/24=7  25/29=8  30/99=9 , generate(cfanigw4)
label var  cfanigw4 "fluency recoded for executive function index"
label define cfanig  0 "0 animals" 1 "1-7 animals"   2 "8-12 animals"   3 "13-15 animals"   4 "16-17 animals"   5 "18-19 animals"   6 "20-21 animals"   7 "22-24 animals"   8 "25-29 animals"   9 "30+ animals"  
label val cfanigw4 cfanig
tab cfanigw4 cfanig
tab cfanigw4 




/****** KEEP ONLY VARIABLES THAT WE DERIVED *******/

keep idauniq finstat4  limitw4 chdw4 hedawanw4 hedawmiw4 hedimanw4 hedimmiw4  diabetesw4 depressw4 respiratw4 strokew4 cancerw4 ///
arthritisw4 arthw4 pa5levelw4 w4pacomb1 w4pased1 w4pased2  cigstw4 eversmkw4 cigstw3 eversmkw3 cigstw2 eversmkw2 cigstw1  ///
alcohw4 maritalw4 iintdatm iintdaty indsex indagerw4 cfmew4 cfanigw4 ///
livpartw4 gaitw4 retiredw4 edu3w4 edu5w4 adlcntw4 iadlcntw4 mobilw4 totcesdw4 depcesdw4 casp19w4 ///
bmival wstval htval sysval diaval hscrp pulval mapval wtval fglu chol hdl trig ldl hba1c cfib wbc ///
fastask fastelig rtin dheas igf1 mch bloodr ///
nettotw_bu_s totinc_bu_s totinc_bu_s totwq5_bu_s yq5_bu_s hedawbp hediabp hedimbp ///
heeyew4 hefrndw4 hepapw4 heopcdiw4 heopfglw4 heopfdiw4 heopfmdw4 ///
heopfcaw4 heopndiw4 heopsdiw4 heoptglw4 heoptdiw4 heoptmdw4 heoptcaw4 heopt96w4 headlcow4 cfwhteyew4 cfwhmeyew4 ///
hefla heflb heflc hefld hefle heflf heslpa heslpb heslpd heslpe heslpf pscedc heill hehelf helwk hehear cfmetm ///
scfeela scfeelb scfeelc scfeeld scfeele scorg09 w4nssec w4nssec8 w4nssec5 w4nssec3 w4xwgt w4lwgt w4scwt ///
scchdg scchdh scchdi scfamg scfmh scfami scfrdg scfrdh scfrdi sclifec pscedf scptrg scchdm scfamm scfrdm

rename (indsex iintdatm iintdaty bmival wstval htval sysval diaval hscrp pulval mapval wtval fglu chol hdl trig ldl hba1c cfib wbc ///
fastask fastelig rtin dheas igf1 mch bloodr nettotw_bu_s totinc_bu_s totwq5_bu_s yq5_bu_s scfeela scfeelb scfeelc scfeeld scfeele scorg09 ///
hefla heflb heflc hefld hefle heflf heslpa heslpb heslpd heslpe heslpf pscedc heill hehelf helwk hehear cfmetm hedawbp hediabp hedimbp ///
scchdg scchdh scchdi scfamg scfmh scfami scfrdg scfrdh scfrdi sclifec pscedf scptrg scchdm scfamm scfrdm) =w4

/* Self-rated health*/
recode hehelfw4 -9/-1=. 1=1 2=2 3=3 4=4 5=5
tab hehelfw4
rename hehelfw4 srh4
tab srh4

recode srh4 1/3=0 4/5=1, generate (srh24)
lab var  srh24 "Fair or poor self-rated health"
label define srh 0 "No" 1"Yes"
lab val srh24 srh
tab srh24
/***** SAVING THE DATA ****/
keep if finstat4 !=""
save "N:\STATS\ELSA\STATA\DATA\wave4_derived.dta", replace
 
