
/* For this example we chose Wave 4 as baseline */ 

/* 1. CORE data from CAPI and SELF-COMPLETION */
use "N:\STATS\ELSA\STATA\DATA\UKDA_STATA_DATASETS\wave_5_elsa_data_v4.dta", clear

set more off
/* 3. MERGE WITH FINANCIAL DERIVED VARIABLES */
merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\Wave_5_financial_derived_variables.dta", ///
keepusing(nettotw_bu_s totinc_bu_s totinc_bu_s totwq5_bu_s yq5_bu_s)
drop if _merge==2 
drop _merge
tab indsex /* The variable to use for sex */
sum indager /* The variable to use for age */
gen indagerw5=indager
replace indagerw5=. if indager==-7
rename (heeye hefrnd hepap heopcdi heopfgl heopfdi heopfmd heopfca heopndi heopsdi heoptgl heoptdi heoptmd heoptca heopt96 headlco ialreye cfwhteye cfwhmeye) =w5


/* A value of -7 indicate age >=90 collapsed to avoid disclosure */
tab finstat

merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\Wave_5_IFS_derived_variables.dta", keepusing(edqual)
drop _merge

/********************************/
/****	EMPLOYMENT STATUS	 ****/
/********************************/


tab wpdes, nolab
tab  wpactpw, nolab
tab wpactse 
tab wpactvw 
tab wpactca 
tab wpactlo 
tab  wpacted 
 tab wpact96
 
*****CREATE LABOUR STATUS****.

gen  paidwork = 0
replace paidwork = 1 if wpactpw==1 
gen  selfempl = 0.
replace selfempl= 1 if wpactse==1 

gen  voluwork = 0
replace voluwork= 1 if wpactvw==1 

gen  careddis = 0
replace careddis= 1 if wpactca==1 

gen  lookfami= 0.
replace lookfami= 1 if wpactlo==1 

gen  noneofthese= 0
replace noneofthese= 1 if wpact96==1 


gen attcours=0
replace attcours=1 if wpacted==1 


gen refused =0
replace refused=1 if  wpactpw==-9 |  wpactse==-9 |  wpactvw==-9 |  wpactca==-9 |  wpactlo==-9 |  wpacted==-9 |  wpact96==-9   
tab  refused



gen retiredw5=2
replace retiredw5=1 if wpdes==1 & paidwork==0 & wpever==1 
replace retiredw5=2 if (paidwork==1 | selfempl==1) & (wpdes !=1)
replace retiredw5=1 if (wpdes==96 & paidwork==0)
replace retiredw5=2 if (wpdes==96 & paidwork==1 & wpdes !=1) 
replace retiredw5=3 if (wpdes==5 & paidwork==0 & lookfami==0) 
replace retiredw5=4 if wpdes==4 | (wpaway >= 1 & wpaway <= 3)
replace retiredw5=5 if(wpever==1 & wpdes !=1) 
replace retiredw5=6 if (wpdes==1 | wpdes==6) & (paidwork==0 & lookfami==1) 
replace retiredw5=1 if(noneofthese==1 & wpdes==1) 
replace retiredw5=2 if(noneofthese==1 & wpdes==2)
replace retiredw5=2 if(noneofthese==1 & wpdes==3) 
replace retiredw5=4 if(noneofthese==1 & wpdes==4) 
replace retiredw5=3 if(noneofthese==1 & wpdes==5) 
replace retiredw5=6 if(noneofthese==1 & wpdes==6 & paidwork==0 ) 
replace retiredw5=5 if refused==1| (wpdes >= 85 & wpdes <= 95) 
lab var retiredw5 "Retirement Status"
label define retiredw5 1 "Completely retired" 2 "In paid employment" 3 "Permanently unable to work" 4 "Not currently in paid employment" 5 "Other" 6 "looking after home or family"
lab val retiredw5 retiredw5
tab retiredw5


/********************************/
/****	  EDUCATION	 ****/
/********************************/

*regroup educational categories 
*Education variable - 5 category
tab edqual

gen edu5w5=edqual
recode edu5w5 1=1  2/3=2   4=3  5/6=4    7=5   -9=. -8=. -3=. 
lab define edu5w5 1 "Degree or equivalent" 2 "A-lev/Higher educa. below degree " 3 "O level or other"  4 "CSE/other" 5 "No qualifications" 
lab var edu5w5 "5-group educational category"
lab val edu5w5 edu5w5
tab edu5w5


*Education variable - 3 category
gen edu3w5=edqual
recode edu3w5 1=1  2/6=2    7=3   -9=. -8=. -3=. 
lab define edu3w5  1 "Degree" 2 "Intermediate" 3 "No qualifications" 
lab var edu3w5 "3-group educational category"
lab val edu3w5 edu3w5
tab edu3w5



/********************************/
/****	  MARITAL STATUS	 ****/
/********************************/

tab dimar 
tab dimar, nolab
tab scptr couple 
tab  couple 
tab  couple , nolab
tab scptr
tab scptr, nolab
gen maritalw5=dimar
recode maritalw5 (1=4) (2/4=1) (5/6=2) (7=3) (8/11=1) (-9=-9) (-8=-8)
label define marital 1 "Married" 2 "Separated divorced" 3 "Widowed" 4 "Never married"
lab val maritalw5 marital
tab maritalw5

tab maritalw5 couple 
tab maritalw5 scptr

gen cohabw5=0
replace cohabw5=0 if ((maritalw5==1) & (scptr==1 | couple==2)) 
replace cohabw5=1 if ((maritalw5==1) & (scptr==2 | couple==3)) 
replace cohabw5=2 if ((maritalw5==2) & (scptr==1 | couple==2)) 
 replace cohabw5=3 if ((maritalw5==2) & (scptr==2 | couple==3)) 
replace cohabw5=4 if ((maritalw5==3) & (scptr==1 | couple==2)) 
replace cohabw5=5 if ((maritalw5==3) & (scptr==2 | couple==3)) 
replace cohabw5=6 if ((maritalw5==4) & (scptr==1 | couple==2)) 
replace cohabw5=7 if ((maritalw5==4) & (scptr==2 | couple==3)) 
lab var cohabw5 "cohabiting status"
label define cohab   0"Married cohab" 1"Married not cohab" 2"Sep/divo cohab" 3"Sep/divo not cohab" 4"Widowed cohab" 5"Widowed not cohab" 6"Never married cohab" 7"Never married not cohab"
lab val cohabw5 cohab
tab cohabw5

gen livpartw5= cohabw5 
recode livpartw5 0=0 2=0 4=0 6=0 1=1 3=1 5=1 7=1
lab var  livpartw5 "whether or not living with partner"
label define ynlab 0"yes" 1"no"
lab val livpartw5 ynlab
tab livpartw5


/********************************/
/******   CHRONIC DISEASE  ******/
/********************************/

*** 1. CHD  ***

tab hedawan /* ANGINA Diagnosis fed forward from previous waves */
tab hedawmi /* MYOCARDIAL INFARCTION Diagnosis fed forward from previous waves */
tab hediman /* ANGINA Diagnosis newly reported */
tab hedimmi /* MYOCARDIAL INFARCTION Diagnosis newly reported */
gen chdw5=0 if hedawan==-1 & hedawmi==-1
replace chdw5=1 if hedawan==2 | hedawmi==3 | hediman==1 | hedimmi==1
/* In ELSA missing values are negative : 
-1	= Item not applicable
-9	= Refusal
-8  = Don't Know
-2  = Schedule not applicable
So we replace all negative values by a '.' to indicate missing */
replace chdw5=. if hediman<0 | hedimmi<0

lab var chdw5 "diagnosed CHD"
lab val chdw5 nylab
tab chdw5


rename hedawan hedawanw5
rename hedawmi hedawmiw5
rename hediman hedimanw5
rename hedimmi hedimmiw5

set more off
*** 2. Diabetes ***
tab hedawdi, nolab
tab hedimdi

gen diabetesw5=0 if hedawdi==-1
replace diabetesw5=1 if hedawdi==7 | hedimdi==1
replace diabetesw5=. if hedimdi<0

lab val diabetesw5 nylab
lab var  diabetesw5 "diagnosed diabetes"
tab diabetesw5

*** 3. Depression ***

gen depressw5=0
replace depressw5=1 if hepsyde ==1
replace depressw5=. if hedibps==-1

lab val depressw5 nylab
lab var  depressw5 "diagnosed depression"
tab depressw5

*** 4. Respiratory ***
tab hediblu
tab hedibas

tab hedbwas,nolab
tab hedbwlu,nolab
tab hedbwas hedbwlu

gen fedresp=0 
replace fedresp=1 if hedbwas==2 | hedbwlu==1
tab fedresp

gen respiratw5=0 if fedresp==0
replace respiratw5=1 if fedresp==1 | hediblu==1 | hedibas==1
replace respiratw5=. if  hediblu==. | hedibas==.

lab val respiratw5 nylab
lab var respiratw5 "asthma or lung disease"
tab respiratw5

*** 5. Stroke ***
gen strokew5=0
replace strokew5=1 if hedawst==8 |  hedimst==1
replace strokew5=. if hedimst<0

lab val strokew5 nylab
lab var strokew5 "diagnosed stroke"
tab strokew5


*** 6. Cancer ***
tab hedibca 
tab hedbwca, nolab

gen cancerw5=0 
replace cancerw5=1 if hedibca==1   | hedbwca==5
replace cancerw5=. if hedibca<0
lab val cancerw5 nylab
lab var cancerw5 "diagnosed cancer"
tab cancerw5


*** 7. Arthritis ***
tab hedbwar, nolab
tab hedibar
tab heartoa, nolab 
tab heartra 
tab heartot

gen arthritisw5=0
replace arthritisw5=1 if hedbwar==3 |  hedibar==1
replace arthritisw5=. if  hedibar<0
lab val arthritisw5 nylab
lab var arthritisw5 "diagnosed arthritis"
tab arthritisw5

gen arthw5=0 if arthritisw5==0
replace arthw5=. if arthritisw5==.
replace arthw5=1 if heartoa==1 
replace arthw5=2 if heartra ==1 
replace arthw5=3 if heartot==1 
replace arthw5=4 if heartoa==-8 | heartra ==-8 | heartot==-8

lab var arthw5 "diagnosed arthritis"
label define arthw5lbl 0 "No" 1 "Osteoarthritis" 2 "Rheumatoid arthritis" 3 "other kind of arthritis" 4 "Don't know"
label values arthw5 arthw5lbl
tab arthw5


/********************************/
/****	LIMITING LONG 
		STANDING ILLNESS	 ****/
/********************************/
tab heill
tab helim
tab heill helim
gen limitw5=0
replace limitw5=1 if heill==1 & helim==1
tab limitw5
lab var  limitw5 "limiting longstanding illness"

label define nylab 0"no" 1"yes"
lab val limitw5 nylab




/********************************/
/****	PHYSICAL ACTIVITY	 ****/
/********************************/

sum  heacta heactb heactc
tab heacta
tab heactb
tab heactc
gen w5pavig1=heacta 
recode w5pavig1 1/3= 1 4=0 
lab var w5pavig1 "wave 4 Any vigorous activity"
tab w5pavig1
gen w5pavig2= heacta 
recode w5pavig2 1=1 2/4 = 0 
lab var w5pavig2 "wave 4 Vigorous activity more than once a week"
tab w5pavig2 
gen w5pamod1=heactb
recode w5pamod1 1/3 = 1 4=0 
lab var w5pamod1 "wave 4 Any moderate activity"
tab w5pamod1
gen w5pamod2=heactb
recode  w5pamod2 1=1 2/4=0 
lab var w5pamod2 "wave 4 Moderate activity more than once a week"
tab w5pamod2
tab w5pavig1 


gen w5pacomb1 = 0 if (heacta >2 & heacta<=4) | ( heactb > 2 & heactb<=4)
replace w5pacomb1 = 1 if (heacta >= 1 & heacta <= 2) | (heactb >= 1 & heactb <= 2) 
tab w5pacomb1
lab var w5pacomb1 "wave 4 vigorous/moderate activity at least once per week"

gen w5pased1 = 1 if (heacta==4 & heactb==4 & heactc ==4) 
replace w5pased1 = 0 if (w5pavig1== 1) | w5pamod1==1 | (heactc>= 1 & heactc <=3)
tab w5pased1
lab var w5pased1 "wave 4 Sedentary - No activity in any category"

gen  w5pased2 = 1 if (heacta==4 & heactb ==4)
replace w5pased2 = 0 if (w5pavig1==1) | w5pamod1== 1

tab w5pased2

lab var w5pased2 "wave 4 Sedentary - No vigorous or moderate activity"



gen pa5levelw5 = 0 if (heacta==4 & heactb== 4) 
replace pa5levelw5 = 1 if (heacta== 4 & heactb==2) | (heacta== 4 &  heactb==3) 
replace pa5levelw5 = 2 if (heacta== 4 &  heactb== 1) | (heacta==3 &  heactb==4)
replace pa5levelw5 = 3  if (heacta==2 &  heactb==3) | (heactb== 1 &  heacta==2) | (heactb==1 &  heacta==3) | (heactb==2 &  heacta== 2) | (heactb==2 &  heacta==3) | (heactb==3 &  heacta==3) 
replace pa5levelw5 = 4 if (heacta==1) 
lab var pa5level "wave 4 5 category PA measure"
lab define pa5level 0 "Sedentary" 4 "Active"
lab val pa5levelw5 pa5level
tab pa5levelw5


gen painactw5=.
replace painactw5=1 if pa5levelw5==0 
replace painactw5=0 if pa5levelw5 >=1
label var painactw5 "Physically inactive"

/* Fruit and veg */
gen fruvegw5=scveg+scfru /* portions of fruit and veg/day*/
gen por5fruvegw5 =.
replace por5fruvegw5 = 1 if fruvegw5>=5 
replace por5fruvegw5=0 if fruvegw5>=0 & fruvegw5<5

label var por5fruvegw5 "At least 5 fruit and vegetables / day"
tab por5fruvegw5



/********************************/
/****		SMOKING			 ****/
/********************************/
rename heska heskaw5
rename hesmk hesmkw5

merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\wave4_derived.dta", keepusing(eversmkw4 cigstw4)
tab _merge
drop _merge

tab eversmkw4 
tab cigstw4
tab heskaw5 hesmkw5
tab heskaw5 hesmkw5, nolab

**ever smoked - need combination of qs on ever smoke from previous wave plus qs on smoke now
** people who tell us before or at wave 4 that have ever smoked
gen eversmkw5 = 1 if eversmkw4==1 | hesmkw5==1
**people who said never smoked at previous waves but smoke at wave 4
replace eversmkw5 = 1 if eversmkw4 ==0 & heskaw5==1

**people who did not have an answer at previous wave and at w5 say never smoked 
replace eversmkw5 = 0 if hesmkw5==2

** people who said never smoked at wave 1 and still say not smoking at wave 4
replace eversmkw5 = 0 if eversmkw4==0 & heskaw5==2

**people who did not have an answer at previous wave and at w5 say  smoked 
replace eversmkw5 = 1 if eversmkw4==. & hesmkw5==1
replace eversmkw5 = . if eversmkw4==. & hesmkw5==.

gen cigstw5 = eversmkw5
replace cigstw5 = 2 if heskaw5==1 & eversmkw5 ==1



lab var cigstw5 "Wave 5 Smoking status"
lab val cigstw5 cigstw
tab eversmkw5
tab cigstw5



/********************************/
/****		  ALCOHOL		 ****/
/********************************/
sum scal7a scako scal7b
tab scal7a
tab scako, nolab
tab scako
tab scal7b
gen alcohw5=scako 
recode alcohw5 3/8=0 2=1 1=1 -9=. -2=. -1=.
label define alcohw5 0"Less than daily" 1"Daily (5/7 days week)"
lab val alcohw5 alcohw5
tab alcohw



/********************************/
/****	  WALKING SPEED 	 ****/
/********************************/
tab mmwlka
tab mmwlkb
tab mmschs
tab mmalone
tab mmhss
tab mmwill
tab mmsaf
tab mmavsp

gen gaitw5 = -99
replace gaitw5=-98 if indager<60 
replace gaitw5=-96 if (gaitw5==-99 & mmschs==-1 & mmalone==-1 & mmhss==-1 & mmwill==-1 & mmsaf==-1 & mmavsp==-1  & mmwala==-1  & mmtrya==-1 & mmwlka==-1 & mmtryb==-1 & mmwlkb==-1)
replace gaitw5=-95 if (gaitw5==-99 & (mmalone==-9 | (mmalone==-1 & mmschs==-9)))
replace gaitw5=-94 if (gaitw5==-99 & mmalone==-8) 
replace gaitw5=-93 if (gaitw5==-99 & mmalone==3) 

replace gaitw5=-92 if (gaitw5==-99 & mmalone==2) 
replace gaitw5=-95 if  (gaitw5==-99 & mmhss==-9) 
replace gaitw5=-94 if (gaitw5==-99 & mmhss==-8) 
replace gaitw5=-91 if (gaitw5==-99 & (mmhss==2 | mmhss==3 | mmhss==4)) 
replace gaitw5=-95 if (gaitw5==-99 & mmwill==-9)
replace gaitw5=-94 if (gaitw5==-99 & mmwill==-8) 
replace gaitw5=-90 if (gaitw5==-99 & mmwill==2)
replace gaitw5=-89 if (gaitw5==-99 & mmsaf==-9) 

replace gaitw5=-88 if (gaitw5==-99 & mmsaf==-8) 
replace gaitw5=-87 if  (gaitw5==-99 & mmsaf==2) 
replace gaitw5=-89 if  (gaitw5==-99 & mmavsp==-9) 
replace gaitw5=-88  if (gaitw5==-99 & mmavsp==-8) 
replace gaitw5=-86 if  (gaitw5==-99 & mmavsp==2) 
replace gaitw5=-95 if  (gaitw5==-99 & mmwala==-9) 
replace gaitw5=-94 if  (gaitw5==-99 & mmwala==-8) 
replace gaitw5=-85 if  (gaitw5==-99 & mmwala==2) 
replace gaitw5=-95 if  (gaitw5==-99 & (mmtrya==-9 | mmtrya==-1 | mmtrya==4 | mmwlka==-9)) 
replace gaitw5=-84  if  (gaitw5==-99 & (mmtrya==2 | mmtrya==3))
replace gaitw5=-82 if  (gaitw5==-99 & ((mmwlka>30 | mmwlka<0.54) & mmwlkb<0)) 
replace gaitw5=-83 if  (gaitw5==-99 & ((mmwlka>30 | mmwlka<0.54) & (mmwlkb>30 | mmwlkb<0.54))) 

replace gaitw5=4.877/(mmwlka+mmwlkb) if  (gaitw5==-99 & (mmwlka<30 & mmwlka>0.54) & (mmwlkb<30 & mmwlkb>0.54))
replace gaitw5 = 2.4384/mmwlka if  (gaitw5==-99 & mmwlka<30 & mmwlka>0.54) 
replace gaitw5 = 2.4384/mmwlkb if  (gaitw5==-99 & mmwlkb<30 & mmwlkb>0.54) 



gen speedindw5 = -1
replace speedindw5 = 1 if  (gaitw5>0  & (mmwlka<30 & mmwlka>0.54) )
replace speedindw5 = 2 if  (gaitw5>0 & (mmwlkb<30 & mmwlkb>0.54) )
replace speedindw5 = 3 if  (gaitw5>0 & (mmwlka<30 & mmwlka>0.54) & (mmwlkb<30 & mmwlkb>0.54))

tab speedindw5

sum gaitw5

gen gaitmisw5=gaitw5 if gaitw5<0
tab gaitmisw5

lab var  gaitw5 "Final wave1 gaitspeed (m/sec)"
lab var speedindw5 "walks used to derive gaitspeed"




label define  speedlab 1 "from walk A only - B extreme etc" 2 "from walk B only - A extreme" 3 "from both walks"

lab val gaitw5 gaitlab 
lab val speedindw5 speedlab
lab val gaitmisw5 gaitlab 

tab gaitw5 if gaitw5<0



	
/********************************/
/****  PHYSICAL FUNCTIONING  ****/
/********************************/
	
	/* ADL COUNT */
sum headldr headlwa headlba headlea headlbe headlwc
tab headldr, nolab
gen adlcntw5=headldr+ headlwa+ headlba +headlea+ headlbe +headlwc
tab adlcntw5
replace adlcntw5=. if adlcntw5<0

	/* IADL COUNT */
sum headlma headlda headlpr headlsh headlte headlco headlme headlho headlmo
tab headlma
gen iadlcntw5=headlma +headlda+headlpr+ headlsh+ headlte+ headlco+ headlme+ headlho +headlmo
tab iadlcntw5
replace iadlcntw5=. if iadlcntw5<0

	/* DIFFICULTIES WITH MOBILITY */
sum hemobwa hemobsi hemobch hemobcs hemobcl hemobst hemobre hemobpu hemobli hemobpi hemob96
tab hemobwa
gen mobilw5=hemobwa +hemobsi+ hemobch+ hemobcs +hemobcl+ hemobst+ hemobre+ hemobpu+ hemobli+ hemobpi 
tab mobilw5
replace mobilw5=. if mobilw5<0
tab mobilw5 hemob96


/*************************************/
/****  DEPRESSIVE SYMPTOMS CES-D  ****/
/*************************************/

sum psceda pscedb pscedc pscedd pscede pscedf pscedg pscedh 


tab	psceda, nolab
tab pscedb
tab pscedc
tab pscedd
tab pscede
tab pscedf, nolab
tab pscedg
tab pscedh

recode	psceda	2=0 -9/-1=.
recode	pscedb	2=0 -9/-1=.
recode pscedc	2=0 -9/-1=.
recode pscedd 2=1 1=0 -9/-1=.
recode pscede 2=0 -9/-1=.
recode pscedf 2=1 1=0 -9/-1=.
recode	pscedg	2=0 -9/-1=.
recode	pscedh	2=0 -9/-1=.




gen totcesdw5=psceda +pscedb +pscedc+ pscedd +pscede +pscedf +pscedg +pscedh
tab totcesdw5

gen depcesdw5=0
replace depcesdw5=1 if totcesdw5>=4
lab var  depcesdw5 "Depressive symptoms CESD"

lab val depcesdw5 dep
tab depcesdw5


/*************************************/
/****  QUALITY OF LIFE CASP  ****/
/*************************************/
sum scqola scqolb scqolc scqold scqole scqolf scqolg scqolh scqoli scqolj scqolk scqoll scqolm scqoln scqolo scqolp scqolq scqolr scqols

gen scqolarc=scqola 
recode scqolarc  (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolbrc=scqolb
recode scqolbrc(1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolfrc=scqolf 
recode scqolfrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolirc=scqoli
recode scqolfrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqoldrc=scqold 
recode scqoldrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolhrc=scqolh
recode scqolhrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)

gen scqolcrc=  scqolc 
recode scqolcrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolcrc (1=0)  (2=1)  (3=2)  (4=3) 

gen scqolerc = scqole
recode scqolerc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolerc (1=0)  (2=1)  (3=2)  (4=3) 

gen scqolgrc = scqolg
recode scqolgrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolgrc (1=0)  (2=1)  (3=2)  (4=3) 

gen scqoljrc  =scqolj
recode scqoljrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqoljrc (1=0)  (2=1)  (3=2)  (4=3) 


gen scqolkrc= scqolk  
recode scqolkrc(1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolkrc (1=0)  (2=1)  (3=2)  (4=3)


gen scqollrc= scqoll 
recode scqollrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqollrc (1=0)  (2=1)  (3=2)  (4=3)


gen scqolmrc=scqolm 
recode scqolmrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolmrc (1=0)  (2=1)  (3=2)  (4=3)

gen  scqolnrc=scqoln  
recode scqolnrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolnrc (1=0)  (2=1)  (3=2)  (4=3)

gen  scqolorc= scqolo 
recode scqolorc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolorc (1=0)  (2=1)  (3=2)  (4=3)


gen  scqolprc =scqolp 
recode scqolprc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolprc (1=0)  (2=1)  (3=2)  (4=3)

gen  scqolqrc = scqolq
recode scqolqrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolqrc (1=0)  (2=1)  (3=2)  (4=3)

 gen scqolrrc =scqolr 
 recode scqolrrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
  recode scqolrrc (1=0)  (2=1)  (3=2)  (4=3)
 
 gen scqolsrc = scqols
 recode scqolsrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
  recode scqolsrc (1=0)  (2=1)  (3=2)  (4=3)
          

gen casp19w5 =scqolarc+ scqolbrc+scqolcrc+ scqoldrc + scqolerc+scqolfrc+ scqolgrc+scqolhrc+ scqolirc+scqoljrc+  scqolkrc + scqollrc + scqolmrc+  scqolnrc + scqolorc + scqolprc + scqolqrc + scqolrrc + scqolsrc 

kdensity casp19w5, normal




**CREATING MEMORY INDEX .
***NB  cflisen and cflisd MUST have -8 coded to 0 in data.

*** Maximum score = 20
tab cflisen
tab cflisd 
recode cflisen  -9/-1=.
recode  cflisd -9/-1=.

gen cfmew5 = cflisen + cflisd  
label var cfmew5 "Memory Index"
tab cfmew5



***CREATING EXECUTIVE FUNCTION INDEX 
***creating new variable cfanig to give scores 1-9
*d/k coded to 0*

tab cfani
recode   cfani   0=0  -9/-1=.  1/7=1  8/12=2  13/15=3  16/17=4  18/19=5  20/21=6  22/24=7  25/29=8  30/99=9 , generate(cfanigw5)
label var  cfanigw5 "fluency recoded for executive function index"
*label define cfanig  0 "0 animals" 1 "1-7 animals"   2 "8-12 animals"   3 "13-15 animals"   4 "16-17 animals"   5 "18-19 animals"   6 "20-21 animals"   7 "22-24 animals"   8 "25-29 animals"   9 "30+ animals"  
label val cfanigw5 cfanig
tab cfanigw5 cfanig
tab cfanigw5 


keep if finstatw5 !=""


/****** KEEP ONLY VARIABLES THAT WE DERIVED *******/

keep idauniq finstatw5  limitw5 chdw5 hedawanw5 hedawmiw5 hedimanw5 hedimmiw5  diabetesw5 depressw5 respiratw5 strokew5 cancerw5 ///
arthritisw5 arthw5 pa5levelw5 w5pacomb1 w5pased1 w5pased2  cigstw5 eversmkw5  cigstw5 eversmkw5 cfmew5 cfanigw5 ///
alcohw5 maritalw5 iintdatm iintdaty indsex indagerw5 painactw5 por5fruvegw5 ///
livpartw5 gaitw5 retiredw5 edu3w5 edu5w5 adlcntw5 iadlcntw5 mobilw5 totcesdw5 depcesdw5 casp19w5 ///
nettotw_bu_s totinc_bu_s totinc_bu_s totwq5_bu_s yq5_bu_s hedawbp hediabp hedimbp ///
heeyew5 hefrndw5 hepapw5 heopcdiw5 heopfglw5 heopfdiw5 heopfmdw5 ///
heopfcaw5 heopndiw5 heopsdiw5 heoptglw5 heoptdiw5 heoptmdw5 heoptcaw5 heopt96w5 headlcow5 cfwhteyew5 cfwhmeyew5 ///
hefla heflb heflc   pscedc heill hehelf helwk hehear  w5nssec w5nssec8 w5nssec5 w5nssec3 w5lwgt w5xwgt w5scwt ///
scfeela scfeelb scfeelc scfeeld scfeele scorg09 ///
scchdg scchdh scchdi scfamg scfamh scfami scfrdg scfrdh scfrdi sclifec pscedf scptrg scchdm scfamm scfrdm

rename (indsex iintdatm iintdaty nettotw_bu_s totinc_bu_s totwq5_bu_s yq5_bu_s ///
scfeela scfeelb scfeelc scfeeld scfeele scorg09 hefla heflb heflc   pscedc ///
heill hehelf helwk hehear hedawbp hediabp hedimbp ///
scchdg scchdh scchdi scfamg scfamh scfami scfrdg scfrdh scfrdi sclifec pscedf scptrg scchdm scfamm scfrdm) =w5

/* Self-rated health*/
recode hehelfw5 -9/-1=. 1=1 2=2 3=3 4=4 5=5
tab hehelfw5
rename hehelfw5 srh5

recode srh5 1/3=0 4/5=1, generate (srh25)
lab var  srh25 "Fair or poor self-rated health"
*label define srh 0 "No" 1"Yes"
lab val srh25 srh
tab srh25
/***** SAVING THE DATA ****/

save "N:\STATS\ELSA\STATA\DATA\wave5_derived.dta", replace
 
