


use "N:\STATS\ELSA\STATA\DATA\UKDA_STATA_DATASETS\wave_6_elsa_data_v2.dta", clear

tab indsex /* The variable to use for sex */
sum indager /* The variable to use for age */
rename indager indagerw6
/* A value of -7 indicate age >=90 collapsed to avoid disclosure */
/********************************/
/****	EMPLOYMENT STATUS	 ****/
/********************************/


tab wpdes, nolab
tab  wpactpw, nolab
tab wpactse 
tab wpactvw 
tab wpactca 
tab wpactlo 
tab  wpacted 
 tab wpact96
 
*****CREATE LABOUR STATUS****.

gen  paidwork = 0
replace paidwork = 1 if wpactpw==1 
gen  selfempl = 0.
replace selfempl= 1 if wpactse==1 

gen  voluwork = 0
replace voluwork= 1 if wpactvw==1 

gen  careddis = 0
replace careddis= 1 if wpactca==1 

gen  lookfami= 0.
replace lookfami= 1 if wpactlo==1 

gen  noneofthese= 0
replace noneofthese= 1 if wpact96==1 


gen attcours=0
replace attcours=1 if wpacted==1 


gen refused =0
replace refused=1 if  wpactpw==-9 |  wpactse==-9 |  wpactvw==-9 |  wpactca==-9 |  wpactlo==-9 |  wpacted==-9 |  wpact96==-9   
tab  refused


gen retiredw6=2
replace retiredw6=1 if WpDes==1 & paidwork==0 & Wpever==1 
replace retiredw6=2 if (paidwork==1 | selfempl==1) & (WpDes !=1)
replace retiredw6=1 if (WpDes==96 & paidwork==0)
replace retiredw6=2 if (WpDes==96 & paidwork==1 & wpdes !=1) 
replace retiredw6=3 if (WpDes==5 & paidwork==0 & lookfami==0) 
replace retiredw6=4 if Wpever==4 | (WpAway >= 1 & WpAway <= 3)
replace retiredw6=5 if(Wpever==1 & WpDes !=1) 
replace retiredw6=6 if (WpDes==1 | WpDes==6) & (paidwork==0 & lookfami==1) 
replace retiredw6=1 if(noneofthese==1 & WpDes==1) 
replace retiredw6=2 if(noneofthese==1 & WpDes==2)
replace retiredw6=2 if(noneofthese==1 & WpDes==3) 
replace retiredw6=4 if(noneofthese==1 & WpDes==4) 
replace retiredw6=3 if(noneofthese==1 & WpDes==5) 
replace retiredw6=6 if(noneofthese==1 & WpDes==6 & paidwork==0 ) 
replace retiredw6=5 if refused==1| (WpDes >= 85 & WpDes <= 95) 
lab var retiredw6 "Retirement Status"
label define retiredw6 1 "Completely retired" 2 "In paid employment" 3 "Permanently unable to work" 4 "Not currently in paid employment" 5 "Other" 6 "looking after home or family"
lab val retiredw6 retiredw6
tab retiredw6



/********************************/
/****	  MARITAL STATUS	 ****/
/********************************/
tab DiMar 
tab DiMar, nolab
tab scprtr couple 

gen maritalw6=DiMar
recode maritalw6 (1=4) (2/4=1) (5/6=2) (7=3) (8/11=1) (-9=.) (-8=.)
label define marital 1 "Married" 2 "Separated divorced" 3 "Widowed" 4 "Never married"
lab val maritalw6 marital
tab maritalw6

tab maritalw6 couple 
tab maritalw6 scprtr

gen cohabw6=0
replace cohabw6=0 if ((maritalw6==1) & (scprtr==1 | couple==2)) 
replace cohabw6=1 if ((maritalw6==1) & (scprtr==2 | couple==3)) 
replace cohabw6=2 if ((maritalw6==2) & (scprtr==1 | couple==2)) 
 replace cohabw6=3 if ((maritalw6==2) & (scprtr==2 | couple==3)) 
replace cohabw6=4 if ((maritalw6==3) & (scprtr==1 | couple==2)) 
replace cohabw6=5 if ((maritalw6==3) & (scprtr==2 | couple==3)) 
replace cohabw6=6 if ((maritalw6==4) & (scprtr==1 | couple==2)) 
replace cohabw6=7 if ((maritalw6==4) & (scprtr==2 | couple==3)) 
lab var cohabw6 "cohabiting status"
label define cohabw6   0"Married cohab" 1"Married not cohab" 2"Sep/divo cohab" 3"Sep/divo not cohab" 4"Widowed cohab" 5"Widowed not cohab" 6"Never married cohab" 7"Never married not cohab"
lab var cohabw6 cohabw6
tab cohabw6

gen livpartw6= cohabw6 
recode livpartw6 0=0 2=0 4=0 6=0 1=1 3=1 5=1 7=1
lab var  livpartw6 "whether or not living with partner"
label define ynlab 0"yes" 1"no"
lab val livpartw6 ynlab
tab livpartw6


/********************************/
/******   CHRONIC DISEASE  ******/
/********************************/

*** 1. CHD  ***

tab hedawan /* ANGINA Diagnosis fed forward from previous waves */
tab hedawmi /* MYOCARDIAL INFARCTION Diagnosis fed forward from previous waves */
tab hediman /* ANGINA Diagnosis newly reported */
tab hedimmi /* MYOCARDIAL INFARCTION Diagnosis newly reported */
gen chdw6=0 if hedawan==-1 & hedawmi==-1
replace chdw6=1 if hedawan==2 | hedawmi==3 | hediman==1 | hedimmi==1
/* In ELSA missing values are negative : 
-1	= Item not applicable
-9	= Refusal
-8  = Don't Know
-2  = Schedule not applicable
So we replace all negative values by a '.' to indicate missing */
replace chdw6=. if hediman<0 | hedimmi<0

rename hedawan hedawanw6
rename hedawmi hedawmiw6
rename hediman hedimanw6
rename hedimmi hedimmiw6

lab var chdw6 "diagnosed CHD"
lab val chdw6 nylab
tab chdw6

*** 2. Diabetes ***
tab hedawdi, nolab
tab hedimdi

gen diabetesw6=0 if hedawdi==-1
replace diabetesw6=1 if hedawdi==7 | hedimdi==1
replace diabetesw6=. if hedimdi<0

lab val diabetesw6 nylab
lab var  diabetesw6 "diagnosed diabetes"
tab diabetesw6

*** 3. Depression ***

gen depressw6=0
replace depressw6=1 if hepsyde ==1
replace depressw6=. if hedibps==-1

lab val depressw6 nylab
lab var  depressw6 "diagnosed depression"
tab depressw6

*** 4. Respiratory ***
tab hediblu
tab hedibas

tab hedbwas,nolab
tab hedbwlu,nolab
tab hedbwas hedbwlu

gen fedresp=0 
replace fedresp=1 if hedbwas==2 | hedbwlu==1
tab fedresp

gen respiratw6=0 if fedresp==0
replace respiratw6=1 if fedresp==1 | hediblu==1 | hedibas==1
replace respiratw6=. if  hediblu==. | hedibas==.

lab val respiratw6 nylab
lab var respiratw6 "asthma or lung disease"
tab respiratw6

*** 5. Stroke ***
gen strokew6=0
replace strokew6=1 if hedawst==8 |  hedimst==1
replace strokew6=. if hedimst<0

lab val strokew6 nylab
lab var strokew6 "diagnosed stroke"
tab strokew6


*** w6. Cancer ***
tab hedibca 
tab hedbwca, nolab

gen cancerw6=0 
replace cancerw6=1 if hedibca==1   | hedbwca==5
replace cancerw6=. if hedibca<0
lab val cancerw6 nylab
lab var cancerw6 "diagnosed cancer"
tab cancerw6


*** 7. Arthritis ***
tab hedbwar, nolab
tab hedibar
tab heartoa, nolab 
tab heartra 
tab heartot

gen arthritisw6=0
replace arthritisw6=1 if hedbwar==3 |  hedibar==1
replace arthritisw6=. if  hedibar<0
lab val arthritisw6 nylab
lab var arthritisw6 "diagnosed arthritis"
tab arthritisw6

gen arthw6=0 if arthritisw6==0
replace arthw6=. if arthritisw6==.
replace arthw6=1 if heartoa==1 
replace arthw6=2 if heartra ==1 
replace arthw6=3 if heartot==1 
replace arthw6=4 if heartoa==-8 | heartra ==-8 | heartot==-8

lab var arthw6 "diagnosed arthritis"
label define arthw6lbl 0 "No" 1 "Osteoarthritis" 2 "Rheumatoid arthritis" 3 "other kind of arthritis" 4 "Don't know"
label values arthw6 arthw6lbl
tab arthw6

/********************************/
/****	LIMITING LONG 
		STANDING ILLNESS	 ****/
/********************************/
tab Heill
tab Helim

gen limitw6=0
replace limitw6=1 if Heill==1 & Helim==1
replace limitw6=. if Heill<0 
tab limitw6
lab var  limitw6 "limiting longstanding illness"

label define nylab 0"no" 1"yes"
lab val limitw6 nylab




/********************************/
/****	PHYSICAL ACTIVITY	 ****/
/********************************/
sum  HeActa HeActb HeActc
tab HeActa
tab HeActb
tab HeActc
rename HeActa heacta
rename HeActb heactb
rename HeActc heactc
gen w6pavig1=heacta 
recode w6pavig1 1/3= 1 4=0 
lab var w6pavig1 "Wave 6 Any vigorous activity"
tab w6pavig1
gen w6pavig2= heacta 
recode w6pavig2 1=1 2/4 = 0 
lab var w6pavig2 "WAVE 6 Vigorous activity more than once a week"
tab w6pavig2 
gen w6pamod1=heactb
recode w6pamod1 1/3 = 1 4=0 
lab var w6pamod1 "Wave 6 Any moderate activity"
tab w6pamod1

gen w6pamod2=heactb
recode  w6pamod2 1=1 2/4=0 
lab var w6pamod2 "Wave 6 Moderate activity more than once a week"
tab w6pamod2
tab w6pavig1 


gen w6pacomb1 = 0 if (heacta >2 & heacta<=4) | ( heactb > 2 & heactb<=4)
replace w6pacomb1 = 1 if (heacta >= 1 & heacta <= 2) | (heactb >= 1 & heactb <= 2) 
tab w6pacomb1
lab var w6pacomb1 "Wave 6 vigorous/moderate activity at least once per week"

gen w6pased1 = 1 if (heacta==4 & heactb==4 & heactc ==4) 
replace w6pased1 = 0 if (w6pavig1== 1) | w6pamod1==1 | (heactc>= 1 & heactc <=3)
tab w6pased1
lab var w6pased1 "Wave 6 Sedentary - No activity in any category"

gen  w6pased2 = 1 if (heacta==4 & heactb ==4)
replace w6pased2 = 0 if (w6pavig1==1) | w6pamod1== 1

tab w6pased2

lab var w6pased2 "Wave 6 Sedentary - No vigorous or moderate activity"




gen pa5levelw6 = 0 if (heacta==4 & heactb== 4) 
replace pa5levelw6 = 1 if (heacta== 4 & heactb==2) | (heacta== 4 &  heactb==3) 
replace pa5levelw6 = 2 if (heacta== 4 &  heactb== 1) | (heacta==3 &  heactb==4)
replace pa5levelw6 = 3  if (heacta==2 &  heactb==3) | (heactb== 1 &  heacta==2) | (heactb==1 &  heacta==3) | (heactb==2 &  heacta== 2) | (heactb==2 &  heacta==3) | (heactb==3 &  heacta==3) 
replace pa5levelw6 = 4 if (heacta==1) 
lab var pa5levelw6 "Wave 6 5 category PA measure"
lab define pa5level 0 "Sedentary"  4 "Active"
lab val pa5levelw6 pa5level
tab pa5levelw6

gen painactw6=.
replace painactw6=1 if pa5levelw6==0 
replace painactw6=0 if pa5levelw6 >=1
label var painactw6 "Physically inactive"

/* Fruit and veg */
gen fruvegw6=scveg+scfru /* portions of fruit and veg/day*/
gen por5fruvegw6 =.
replace por5fruvegw6 = 1 if fruvegw6>=5 
replace por5fruvegw6=0 if fruvegw6>=0 & fruvegw6<5

label var por5fruvegw6 "At least 5 fruit and vegetables / day"
tab por5fruvegw6

/********************************/
/****		SMOKING			 ****/
/********************************/
rename HESka heskaw6
rename HeSmk hesmkw6
set more off

merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\wave5_derived.dta", keepusing(cigstw5 eversmkw5)
tab _merge
drop _merge


tab heskaw6 hesmkw6
tab heskaw6 hesmkw6, nolab

**ever smoked - need combination of qs on ever smoke from previous wave plus qs on smoke now
** people who said before or at wave 6 that have ever smoked
gen eversmkw6 = 1 if eversmkw5==1 | hesmkw6==1 
**people who said never smoked at previous waves but smoke at wave 5
replace eversmkw6 = 1 if eversmkw5 ==0 & heskaw6==1

** people who said never smoked at wave 4 and still say not smoking at wave 5
replace eversmkw6 = 0 if eversmkw5==0 & ( heskaw6==2 | hesmkw6==2 )

**people who did not have an answer at previous wave and at w6 say never smoked 
replace eversmkw6 = 0 if eversmkw5==. & hesmkw6==2
**people who did not have an answer at previous wave and at w6 say  smoked 
replace eversmkw6 = 1 if eversmkw5==. & (heskaw6==1 | hesmkw6)
replace eversmkw6 = . if eversmkw5==. & hesmkw6==.


gen cigstw6 = eversmkw6
replace cigstw6 = 2 if heskaw6==1 & eversmkw6 ==1

lab var cigstw5 "Wave 5 Smoking status"
lab var cigstw6 "Wave 6 Smoking status"
lab define cigst 0 "Never smoker" 1 "Ex-smoker" 2 "Current smoker"
lab val cigstw5 cigst
lab val cigstw6 cigst

tab cigstw5
tab cigstw6

/********************************/
/****		  ALCOHOL		 ****/
/********************************/
sum scal7a scako scal7b
tab scal7a
tab scako, nolab
tab scal7b
gen alcohw6=scako 
recode alcohw6 3/8=0 2=1 1=1 -9=. -2=.
label define alcohw6 0"Less than daily" 1"Daily (5/7 days week)"
lab val alcohw6 alcohw6
tab alcohw6



/********************************/
/****	  WALKING SPEED 	 ****/
/********************************/
tab MMWlkA
tab MMWlkB
tab MmSchs
tab MmAlone
tab MmHSS
tab MmWill
tab MmSaf
tab MmAvsp

rename MMWlkA mmwlka
rename MMWlkB mmwlkb
rename MmSchs mmschs
rename MmAlone mmalone
rename MmHSS mmhss
rename MmWill mmwill
rename MmSaf mmsaf
rename MmAvsp mmavsp
rename MmWala mmwala
rename MmTrya mmtrya
rename MmTryb mmtryb

gen gaitw6 = -99
replace gaitw6=-98 if indager<60 
replace gaitw6=-96 if (gaitw6==-99 & mmschs==-1 & mmalone==-1 & mmhss==-1 & mmwill==-1 & mmsaf==-1 & mmavsp==-1  & mmwala==-1  & mmtrya==-1 & mmwlka==-1 & mmtryb==-1 & mmwlkb==-1)
replace gaitw6=-95 if (gaitw6==-99 & (mmalone==-9 | (mmalone==-1 & mmschs==-9)))
replace gaitw6=-94 if (gaitw6==-99 & mmalone==-8) 
replace gaitw6=-93 if (gaitw6==-99 & mmalone==3) 

replace gaitw6=-92 if (gaitw6==-99 & mmalone==2) 
replace gaitw6=-95 if  (gaitw6==-99 & mmhss==-9) 
replace gaitw6=-94 if (gaitw6==-99 & mmhss==-8) 
replace gaitw6=-91 if (gaitw6==-99 & (mmhss==2 | mmhss==3 | mmhss==4)) 
replace gaitw6=-95 if (gaitw6==-99 & mmwill==-9)
replace gaitw6=-94 if (gaitw6==-99 & mmwill==-8) 
replace gaitw6=-90 if (gaitw6==-99 & mmwill==2)
replace gaitw6=-89 if (gaitw6==-99 & mmsaf==-9) 

replace gaitw6=-88 if (gaitw6==-99 & mmsaf==-8) 
replace gaitw6=-87 if  (gaitw6==-99 & mmsaf==2) 
replace gaitw6=-89 if  (gaitw6==-99 & mmavsp==-9) 
replace gaitw6=-88  if (gaitw6==-99 & mmavsp==-8) 
replace gaitw6=-86 if  (gaitw6==-99 & mmavsp==2) 
replace gaitw6=-95 if  (gaitw6==-99 & mmwala==-9) 
replace gaitw6=-94 if  (gaitw6==-99 & mmwala==-8) 
replace gaitw6=-85 if  (gaitw6==-99 & mmwala==2) 
replace gaitw6=-95 if  (gaitw6==-99 & (mmtrya==-9 | mmtrya==-1 | mmtrya==4 | mmwlka==-9)) 
replace gaitw6=-84  if  (gaitw6==-99 & (mmtrya==2 | mmtrya==3))
replace gaitw6=-82 if  (gaitw6==-99 & ((mmwlka>30 | mmwlka<0.54) & mmwlkb<0)) 
replace gaitw6=-83 if  (gaitw6==-99 & ((mmwlka>30 | mmwlka<0.54) & (mmwlkb>30 | mmwlkb<0.54))) 

replace gaitw6=4.877/(mmwlka+mmwlkb) if  (gaitw6==-99 & (mmwlka<30 & mmwlka>0.54) & (mmwlkb<30 & mmwlkb>0.54))
replace gaitw6 = 2.4384/mmwlka if  (gaitw6==-99 & mmwlka<30 & mmwlka>0.54) 
replace gaitw6 = 2.4384/mmwlkb if  (gaitw6==-99 & mmwlkb<30 & mmwlkb>0.54) 



gen speedindw6 = -1
replace speedindw6 = 1 if  (gaitw6>0  & (mmwlka<30 & mmwlka>0.54) )
replace speedindw6 = 2 if  (gaitw6>0 & (mmwlkb<30 & mmwlkb>0.54) )
replace speedindw6 = 3 if  (gaitw6>0 & (mmwlka<30 & mmwlka>0.54) & (mmwlkb<30 & mmwlkb>0.54))

tab speedindw6

sum gaitw6

gen gaitmisw6=gaitw6 if gaitw6<0
tab gaitmisw6

lab var  gaitw6 "Final wave1 gaitspeed (m/sec)"
lab var speedindw6 "walks used to derive gaitspeed"


lab val gaitw6 gaitlab 
lab val speedindw6 speedlab
lab val gaitmisw6 gaitlab 

tab gaitw6 if gaitw6<0



	
/********************************/
/****  PHYSICAL FUNCTIONING  ****/
/********************************/
	
	/* ADL COUNT */
sum headldr headlwa headlba headlea headlbe headlwc
tab headldr, nolab
gen adlcntw6=headldr+ headlwa+ headlba +headlea+ headlbe +headlwc
tab adlcntw6
replace adlcntw6=. if adlcntw6<0

	/* IADL COUNT */
sum headlma headlpr headlsh headlph headlme headlho headlmo
tab headlma
gen iadlcntw6=headlma +headlpr+ headlsh+ headlph+ headlme+ headlho +headlmo
tab iadlcntw6
replace iadlcntw6=. if iadlcntw6<0

	/* DIFFICULTIES WITH MOBILITY */
sum hemobwa hemobsi hemobch hemobcs hemobcl hemobst hemobre hemobpu hemobli hemobpi hemob96
tab hemobwa
gen mobilw6=hemobwa +hemobsi+ hemobch+ hemobcs +hemobcl+ hemobst+ hemobre+ hemobpu+ hemobli+ hemobpi 
tab mobilw6
replace mobilw6=. if mobilw6<0
tab mobilw6 hemob96


/*************************************/
/****  DEPRESSIVE SYMPTOMS CES-D  ****/
/*************************************/

tab	PScedA, nolab
tab PScedB
tab PScedC
tab PScedD
tab PScedE
tab PScedF, nolab
tab PScedG
tab PScedH

recode	PScedA	2=0 -9/-1=.
recode	PScedB	2=0 -9/-1=.
recode PScedC	2=0 -9/-1=.
recode PScedD 2=1 1=0 -9/-1=. /* this item is reverse coded */
recode PScedE 2=0 -9/-1=.
recode PScedF 2=1 1=0 -9/-1=. /* this item is reverse coded */
recode	PScedG	2=0 -9/-1=.
recode	PScedH	2=0 -9/-1=.




gen totcesdw6=PScedA +PScedB +PScedC+ PScedD+PScedE +PScedF +PScedG +PScedH
tab totcesdw6

gen depcesdw6=0
replace depcesdw6=1 if totcesdw6>=4
tab depcesdw6

/*************************************/
/****  QUALITY OF LIFE CASP  ****/
/*************************************/
sum scqola scqolb scqolc scqold scqole scqolf scqolg scqolh scqoli scqolj scqolk scqoll scqolm scqoln scqolo scqolp scqolq scqolr scqols

gen scqolarc=scqola 
recode scqolarc  (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolbrc=scqolb
recode scqolbrc(1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolfrc=scqolf 
recode scqolfrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolirc=scqoli
recode scqolfrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqoldrc=scqold 
recode scqoldrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolhrc=scqolh
recode scqolhrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)

gen scqolcrc=  scqolc 
recode scqolcrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolcrc (1=0)  (2=1)  (3=2)  (4=3) 

gen scqolerc = scqole
recode scqolerc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolerc (1=0)  (2=1)  (3=2)  (4=3) 

gen scqolgrc = scqolg
recode scqolgrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolgrc (1=0)  (2=1)  (3=2)  (4=3) 

gen scqoljrc  =scqolj
recode scqoljrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqoljrc (1=0)  (2=1)  (3=2)  (4=3) 


gen scqolkrc= scqolk  
recode scqolkrc(1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolkrc (1=0)  (2=1)  (3=2)  (4=3)


gen scqollrc= scqoll 
recode scqollrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqollrc (1=0)  (2=1)  (3=2)  (4=3)


gen scqolmrc=scqolm 
recode scqolmrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolmrc (1=0)  (2=1)  (3=2)  (4=3)

gen  scqolnrc=scqoln  
recode scqolnrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolnrc (1=0)  (2=1)  (3=2)  (4=3)

gen  scqolorc= scqolo 
recode scqolorc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolorc (1=0)  (2=1)  (3=2)  (4=3)


gen  scqolprc =scqolp 
recode scqolprc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolprc (1=0)  (2=1)  (3=2)  (4=3)

gen  scqolqrc = scqolq
recode scqolqrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolqrc (1=0)  (2=1)  (3=2)  (4=3)

 gen scqolrrc =scqolr 
 recode scqolrrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
  recode scqolrrc (1=0)  (2=1)  (3=2)  (4=3)
 
 gen scqolsrc = scqols
 recode scqolsrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
  recode scqolsrc (1=0)  (2=1)  (3=2)  (4=3)
          

gen casp19w6 =scqolarc+ scqolbrc+scqolcrc+ scqoldrc + scqolerc+scqolfrc+ scqolgrc+scqolhrc+ scqolirc+scqoljrc+  scqolkrc + scqollrc + scqolmrc+  scqolnrc + scqolorc + scqolprc + scqolqrc + scqolrrc + scqolsrc 


/*************************************/
		/* COGNITIVE FUNCTION */
/*************************************/

**CREATING MEMORY INDEX .
***NB  cflisen and cflisd MUST have -8 coded to 0 in data.

*** Maximum score = 20
tab CfLisEn
tab CfLisD 
recode CfLisEn  -9/-1=.
recode  CfLisD -9/-1=.

gen cfmew6 = CfLisEn + CfLisD  
label var cfmew6 "Memory Index"
tab cfmew6



/* NO COGNITIVE EXECUTIVE FUNCTION AT THIS WAVE */



/* 2. MERGE WITH NURSE DATA */
/* Note: Only nurse data at W2 W4 and W6*/
/* Example of selection of variables to merge using the "keepusing" option */
merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\UKDA_STATA_DATASETS\wave_6_elsa_nurse_data_v2.dta", ///
keepusing(BMIVAL WSTVAL HTVAL SYSVAL DIAVAL PULVAL MAPVAL WTVAL hscrp  fglu chol hdl trig ldl hba1c cfib wbc fastask fastelig rtin igf1 mch )
drop if _merge==2 
drop _merge
/* We want to keep everyone from core data even if they have missing values on 
	nurse visit for the moment */

/* 3. MERGE WITH FINANCIAL DERIVED VARIABLES */

merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\Wave_6_financial_derived_variables.dta", ///
keepusing(nettotw_bu_s totinc_bu_s totinc_bu_s totwq5_bu_s yq5_bu_s)
drop if _merge==2 
drop _merge

merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\Wave_6_IFS_derived_variables.dta", keepusing(edqual)
drop _merge
rename edqual edqualw6
*regroup educational categories 
*Education variable - 5 category


gen edu5w6=edqualw6
recode edu5w6 1=1  2/3=2   4=3  5/6=4    7=5   -9=. -8=. -3=. -1=. -2=.
lab define edu5w6 1 "Degree or equivalent" 2 "A-lev/Higher educa. below degree " 3 "O level or other"  4 "CSE/other" 5 "No qualifications" 
lab var edu5w6 "5-group educational category"
lab val edu5w6 edu5w6
tab edu5w6
compress

*Education variable - 3 category
gen edu3w6=edqualw6
recode edu3w6 1=1  2/6=2    7=3   -9=. -8=. -3=. -1=. -2=.
lab define edu3w6  1 "Degree" 2 "Intermediate" 3 "No qualifications" 
lab var edu3w6 "3-group educational category"
lab val edu3w6 edu3w6
tab edu3w6




rename (HeEye Heeyea Hefrnd Hepap heopcdi heopfgl heopfdi heopfmd heopfca heopndi heopsdi heoptgl heoptdi heoptmd heoptca HeOpt96 hedreyr headlco ialreye cfwhteye CfWhatIM) =w6



keep idauniq finstatw6  limitw6 chdw6 hedawanw6 hedawmiw6 hedimanw6 hedimmiw6  diabetesw6 depressw6 respiratw6 strokew6 cancerw6 ///
arthritisw6 arthw6 pa5levelw6 w6pacomb1 w6pased1 w6pased2  cigstw5 eversmkw5 cigstw6 eversmkw6 edu5w6 edu3w6 ///
alcohw6 maritalw6 iintdatm iintdaty indsex indagerw6 cfmew6 painactw6 por5fruvegw6 ///
livpartw6 gaitw6 retiredw6 adlcntw6 iadlcntw6 mobilw6 totcesdw6 depcesdw6 casp19w6 ///
BMIVAL WSTVAL HTVAL SYSVAL DIAVAL PULVAL MAPVAL WTVAL hscrp  fglu chol hdl trig ldl hba1c cfib wbc fastask fastelig rtin igf1 mch ///
nettotw_bu_s totinc_bu_s totinc_bu_s totwq5_bu_s yq5_bu_s hedawbp hediabp hedimbp ///
HeEyew6 Heeyeaw6 Hefrndw6 Hepapw6 heopcdiw6 heopfglw6 heopfdiw6 heopfmdw6 heopfcaw6 ///
heopndiw6 heopsdiw6 heoptglw6 heoptdiw6 heoptmdw6 heoptcaw6 HeOpt96w6 hedreyrw6 headlcow6 cfwhteyew6 CfWhatIMw6 ///
HeFla HeFlb HeFlc heslpa heslpb heslpd heslpe heslpf PScedC Hehelf HeLWk HeHear  ///
scfeela scfeelb scfeelc scfeeld scfeele scorg09  ///
w6nssec8 w6nssec5 w6nssec3 w6lwgt w6xwgt w6scwt w6sscwt ///
scchdg scchdh scchdi scfamg scfamh scfami scfrdg scfrdh scfrdi sclifec PScedF scptrg scchdm scfamm scfrdm

rename (indsex iintdatm iintdaty BMIVAL WSTVAL HTVAL SYSVAL DIAVAL PULVAL MAPVAL WTVAL ///
 hscrp  fglu chol hdl trig ldl hba1c cfib wbc fastask fastelig rtin igf1 mch ///
nettotw_bu_s totinc_bu_s totwq5_bu_s yq5_bu_s scfeela scfeelb scfeelc scfeeld scfeele scorg09 ///
HeFla HeFlb HeFlc heslpa heslpb heslpd heslpe heslpf PScedC Hehelf HeLWk HeHear  hedawbp hediabp hedimbp ///
scchdg scchdh scchdi scfamg scfamh scfami scfrdg scfrdh scfrdi sclifec PScedF scptrg scchdm scfamm scfrdm ) =w6

 /* Self-rated health*/
recode Hehelfw6 -9/-1=. 1=1 2=2 3=3 4=4 5=5
tab Hehelfw6
rename Hehelfw6 srh6


recode srh6 1/3=0 4/5=1, generate (srh26)
lab var  srh26 "Fair or poor self-rated health"

lab val srh26 srh
tab srh26

keep if finstatw6 !=.

save "N:\STATS\ELSA\STATA\DATA\wave6_derived.dta", replace
 
