
set more off
use "N:\STATS\ELSA\STATA\DATA\UKDA_STATA_DATASETS\wave_7_elsa_data.dta", clear

tab indsex /* The variable to use for sex */


/********************************/
/****	EMPLOYMENT STATUS	 ****/
/********************************/


tab  wpactpw, nolab
tab wpactse 
tab wpactvw 
tab wpactca 
tab wpactlo 
tab  wpacted 
 tab wpact96
 
*****CREATE LABOUR STATUS****.

gen  paidwork = 0
replace paidwork = 1 if wpactpw==1 
gen  selfempl = 0.
replace selfempl= 1 if wpactse==1 

gen  voluwork = 0
replace voluwork= 1 if wpactvw==1 

gen  careddis = 0
replace careddis= 1 if wpactca==1 

gen  lookfami= 0.
replace lookfami= 1 if wpactlo==1 

gen  noneofthese= 0
replace noneofthese= 1 if wpact96==1 


gen attcours=0
replace attcours=1 if wpacted==1 


gen refused =0
replace refused=1 if  wpactpw==-9 |  wpactse==-9 |  wpactvw==-9 |  wpactca==-9 |  wpactlo==-9 |  wpacted==-9 |  wpact96==-9   
tab  refused


gen retiredw7=2
replace retiredw7=1 if WpDes==1 & paidwork==0 & Wpever==1 
replace retiredw7=2 if (paidwork==1 | selfempl==1) & (WpDes !=1)
replace retiredw7=1 if (WpDes==96 & paidwork==0)
replace retiredw7=2 if (WpDes==96 & paidwork==1 & WpDes !=1) 
replace retiredw7=3 if (WpDes==5 & paidwork==0 & lookfami==0) 
replace retiredw7=4 if Wpever==4 | (WpAway >= 1 & WpAway <= 3)
replace retiredw7=5 if(Wpever==1 & WpDes !=1) 
replace retiredw7=6 if (WpDes==1 | WpDes==6) & (paidwork==0 & lookfami==1) 
replace retiredw7=1 if(noneofthese==1 & WpDes==1) 
replace retiredw7=2 if(noneofthese==1 & WpDes==2)
replace retiredw7=2 if(noneofthese==1 & WpDes==3) 
replace retiredw7=4 if(noneofthese==1 & WpDes==4) 
replace retiredw7=3 if(noneofthese==1 & WpDes==5) 
replace retiredw7=6 if(noneofthese==1 & WpDes==6 & paidwork==0 ) 
replace retiredw7=5 if refused==1| (WpDes >= 85 & WpDes <= 95) 
lab var retiredw7 "Retirement Status"
lab val retiredw7 retiredw7
tab retiredw7



/********************************/
/****	  MARITAL STATUS	 ****/
/********************************/
tab DiMar 
tab DiMar, nolab
tab scprtr couple 

gen maritalw7=DiMar
recode maritalw7 (1=4) (2/4=1) (5/6=2) (7=3) (8/11=1) (-9=.) (-8=.)

lab val maritalw7 marital
tab maritalw7

tab maritalw7 couple 
tab maritalw7 scprtr

gen cohabw7=0
replace cohabw7=0 if ((maritalw7==1) & (scprtr==1 | couple==2)) 
replace cohabw7=1 if ((maritalw7==1) & (scprtr==2 | couple==3)) 
replace cohabw7=2 if ((maritalw7==2) & (scprtr==1 | couple==2)) 
 replace cohabw7=3 if ((maritalw7==2) & (scprtr==2 | couple==3)) 
replace cohabw7=4 if ((maritalw7==3) & (scprtr==1 | couple==2)) 
replace cohabw7=5 if ((maritalw7==3) & (scprtr==2 | couple==3)) 
replace cohabw7=6 if ((maritalw7==4) & (scprtr==1 | couple==2)) 
replace cohabw7=7 if ((maritalw7==4) & (scprtr==2 | couple==3)) 
lab var cohabw7 "cohabiting status"
lab var cohabw7 cohabw7
tab cohabw7

gen livpartw7= cohabw7 
recode livpartw7 0=0 2=0 4=0 6=0 1=1 3=1 5=1 7=1
lab var  livpartw7 "whether or not living with partner"

lab val livpartw7 ynlab
tab livpartw7


/********************************/
/******   CHRONIC DISEASE  ******/
/********************************/

*** 1. CHD  ***

tab hedawan /* ANGINA Diagnosis fed forward from previous waves */
tab hedawmi /* MYOCARDIAL INFARCTION Diagnosis fed forward from previous waves */
tab hediman /* ANGINA Diagnosis newly reported */
tab hedimmi /* MYOCARDIAL INFARCTION Diagnosis newly reported */
gen chdw7=0 if hedawan==-1 & hedawmi==-1
replace chdw7=1 if hedawan==2 | hedawmi==3 | hediman==1 | hedimmi==1
/* In ELSA missing values are negative : 
-1	= Item not applicable
-9	= Refusal
-8  = Don't Know
-2  = Schedule not applicable
So we replace all negative values by a '.' to indicate missing */
replace chdw7=. if hediman<0 | hedimmi<0

rename hedawan hedawanw7
rename hedawmi hedawmiw7
rename hediman hedimanw7
rename hedimmi hedimmiw7

lab var chdw7 "diagnosed CHD"
lab val chdw7 nylab
tab chdw7

*** 2. Diabetes ***
tab hedawdi, nolab
tab hedimdi

gen diabetesw7=0 if hedawdi==-1
replace diabetesw7=1 if hedawdi==7 | hedimdi==1
replace diabetesw7=. if hedimdi<0

lab val diabetesw7 nylab
lab var  diabetesw7 "diagnosed diabetes"
tab diabetesw7

*** 3. Depression ***

gen depressw7=0
replace depressw7=1 if hepsyde ==1
replace depressw7=. if hedibps==-1

lab val depressw7 nylab
lab var  depressw7 "diagnosed depression"
tab depressw7

*** 4. Respiratory ***
tab hediblu
tab hedibas

tab hedbwas,nolab
tab hedbwlu,nolab
tab hedbwas hedbwlu

gen fedresp=0 
replace fedresp=1 if hedbwas==2 | hedbwlu==1
tab fedresp

gen respiratw7=0 if fedresp==0
replace respiratw7=1 if fedresp==1 | hediblu==1 | hedibas==1
replace respiratw7=. if  hediblu==. | hedibas==.

lab val respiratw7 nylab
lab var respiratw7 "asthma or lung disease"
tab respiratw7

*** 5. Stroke ***
gen strokew7=0
replace strokew7=1 if hedawst==8 |  hedimst==1
replace strokew7=. if hedimst<0

lab val strokew7 nylab
lab var strokew7 "diagnosed stroke"
tab strokew7


*** w7. Cancer ***
tab hedibca 
tab hedbwca, nolab

gen cancerw7=0 
replace cancerw7=1 if hedibca==1   | hedbwca==5
replace cancerw7=. if hedibca<0
lab val cancerw7 nylab
lab var cancerw7 "diagnosed cancer"
tab cancerw7


*** 7. Arthritis ***
tab hedbwar, nolab
tab hedibar
tab heartoa, nolab 
tab heartra 
tab heartot

gen arthritisw7=0
replace arthritisw7=1 if hedbwar==3 |  hedibar==1
replace arthritisw7=. if  hedibar<0
lab val arthritisw7 nylab
lab var arthritisw7 "diagnosed arthritis"
tab arthritisw7

gen arthw7=0 if arthritisw7==0
replace arthw7=. if arthritisw7==.
replace arthw7=1 if heartoa==1 
replace arthw7=2 if heartra ==1 
replace arthw7=3 if heartot==1 
replace arthw7=4 if heartoa==-8 | heartra ==-8 | heartot==-8

lab var arthw7 "diagnosed arthritis"

label values arthw7 arthw7lbl
tab arthw7


/********************************/
/****	PHYSICAL ACTIVITY	 ****/
/********************************/
sum  HeActa HeActb HeActc
tab HeActa
tab HeActb
tab HeActc
rename HeActa heacta
rename HeActb heactb
rename HeActc heactc
gen w7pavig1=heacta 
recode w7pavig1 1/3= 1 4=0 
lab var w7pavig1 "wave 7 Any vigorous activity"
tab w7pavig1
gen w7pavig2= heacta 
recode w7pavig2 1=1 2/4 = 0 
lab var w7pavig2 "wave 7 Vigorous activity more than once a week"
tab w7pavig2 
gen w7pamod1=heactb
recode w7pamod1 1/3 = 1 4=0 
lab var w7pamod1 "wave 7 Any moderate activity"
tab w7pamod1

gen w7pamod2=heactb
recode  w7pamod2 1=1 2/4=0 
lab var w7pamod2 "wave 7 Moderate activity more than once a week"
tab w7pamod2
tab w7pavig1 


gen w7pacomb1 = 0 if (heacta >2 & heacta<=4) | ( heactb > 2 & heactb<=4)
replace w7pacomb1 = 1 if (heacta >= 1 & heacta <= 2) | (heactb >= 1 & heactb <= 2) 
tab w7pacomb1
lab var w7pacomb1 "wave 7 vigorous/moderate activity at least once per week"

gen w7pased1 = 1 if (heacta==4 & heactb==4 & heactc ==4) 
replace w7pased1 = 0 if (w7pavig1== 1) | w7pamod1==1 | (heactc>= 1 & heactc <=3)
tab w7pased1
lab var w7pased1 "wave 7 Sedentary - No activity in any category"

gen  w7pased2 = 1 if (heacta==4 & heactb ==4)
replace w7pased2 = 0 if (w7pavig1==1) | w7pamod1== 1

tab w7pased2

lab var w7pased2 "wave 7 Sedentary - No vigorous or moderate activity"




gen pa5levelw7 = 0 if (heacta==4 & heactb== 4) 
replace pa5levelw7 = 1 if (heacta== 4 & heactb==2) | (heacta== 4 &  heactb==3) 
replace pa5levelw7 = 2 if (heacta== 4 &  heactb== 1) | (heacta==3 &  heactb==4)
replace pa5levelw7 = 3  if (heacta==2 &  heactb==3) | (heactb== 1 &  heacta==2) | (heactb==1 &  heacta==3) | (heactb==2 &  heacta== 2) | (heactb==2 &  heacta==3) | (heactb==3 &  heacta==3) 
replace pa5levelw7 = 4 if (heacta==1) 
lab var pa5levelw7 "wave 7 5 category PA measure"

lab val pa5levelw7 pa5level
tab pa5levelw7

gen painactw7=.
replace painactw7=1 if pa5levelw7==0 
replace painactw7=0 if pa5levelw7 >=1
label var painactw7 "Physically inactive"


/********************************/
/****		SMOKING			 ****/
/********************************/
rename HESka heskaw7
rename HeSmk hesmkw7
set more off
merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\wave6_derived.dta", keepusing(cigstw6 eversmkw6 )
tab _merge
drop _merge


**ever smoked - need combination of qs on ever smoke from previous wave plus qs on smoke now
** people who said before or at wave 7 that have ever smoked
gen eversmkw7 = 1 if eversmkw6==1 | hesmkw7==1 
**people who said never smoked at previous waves but smoke at wave 5
replace eversmkw7 = 1 if eversmkw6 ==0 & heskaw7==1

** people who said never smoked at wave 4 and still say not smoking at wave 5
replace eversmkw7 = 0 if eversmkw6==0 & ( heskaw7==2 | hesmkw7==2 )

**people who did not have an answer at previous wave and at w7 say never smoked 
replace eversmkw7 = 0 if eversmkw6==. & hesmkw7==2
**people who did not have an answer at previous wave and at w7 say  smoked 
replace eversmkw7 = 1 if eversmkw6==. & (heskaw7==1 | hesmkw7)
replace eversmkw7 = . if eversmkw6==. & hesmkw7==.


gen cigstw7 = eversmkw7
replace cigstw7 = 2 if heskaw7==1 & eversmkw7 ==1


tab eversmkw6
tab eversmkw7

lab var cigstw7 "wave 7 Smoking status"

lab val cigstw7 cigst

tab cigstw6
tab cigstw7

/********************************/
/****		  ALCOHOL		 ****/
/********************************/
sum scal7a scako scal7b
tab scal7a
tab scako, nolab
tab scal7b
gen alcohw7=scako 
recode alcohw7 3/8=0 2=1 1=1 -9=. -2=.

lab val alcohw7 alcohw7
tab alcohw7



/********************************/
/****	  WALKING SPEED 	 ****/
/********************************/
tab MMWlkA
tab MMWlkB
tab MmSchs
tab MmAlone
tab MmHSS
tab MmWill
tab MmSaf
tab MmAvsp

rename MMWlkA mmwlka
rename MMWlkB mmwlkb
rename MmSchs mmschs
rename MmAlone mmalone
rename MmHSS mmhss
rename MmWill mmwill
rename MmSaf mmsaf
rename MmAvsp mmavsp
rename MmWala mmwala
rename MmTrya mmtrya
rename MmTryb mmtryb

gen gaitw7 = -99
replace gaitw7=-98 if indager<60 
replace gaitw7=-96 if (gaitw7==-99 & mmschs==-1 & mmalone==-1 & mmhss==-1 & mmwill==-1 & mmsaf==-1 & mmavsp==-1  & mmwala==-1  & mmtrya==-1 & mmwlka==-1 & mmtryb==-1 & mmwlkb==-1)
replace gaitw7=-95 if (gaitw7==-99 & (mmalone==-9 | (mmalone==-1 & mmschs==-9)))
replace gaitw7=-94 if (gaitw7==-99 & mmalone==-8) 
replace gaitw7=-93 if (gaitw7==-99 & mmalone==3) 

replace gaitw7=-92 if (gaitw7==-99 & mmalone==2) 
replace gaitw7=-95 if  (gaitw7==-99 & mmhss==-9) 
replace gaitw7=-94 if (gaitw7==-99 & mmhss==-8) 
replace gaitw7=-91 if (gaitw7==-99 & (mmhss==2 | mmhss==3 | mmhss==4)) 
replace gaitw7=-95 if (gaitw7==-99 & mmwill==-9)
replace gaitw7=-94 if (gaitw7==-99 & mmwill==-8) 
replace gaitw7=-90 if (gaitw7==-99 & mmwill==2)
replace gaitw7=-89 if (gaitw7==-99 & mmsaf==-9) 

replace gaitw7=-88 if (gaitw7==-99 & mmsaf==-8) 
replace gaitw7=-87 if  (gaitw7==-99 & mmsaf==2) 
replace gaitw7=-89 if  (gaitw7==-99 & mmavsp==-9) 
replace gaitw7=-88  if (gaitw7==-99 & mmavsp==-8) 
replace gaitw7=-86 if  (gaitw7==-99 & mmavsp==2) 
replace gaitw7=-95 if  (gaitw7==-99 & mmwala==-9) 
replace gaitw7=-94 if  (gaitw7==-99 & mmwala==-8) 
replace gaitw7=-85 if  (gaitw7==-99 & mmwala==2) 
replace gaitw7=-95 if  (gaitw7==-99 & (mmtrya==-9 | mmtrya==-1 | mmtrya==4 | mmwlka==-9)) 
replace gaitw7=-84  if  (gaitw7==-99 & (mmtrya==2 | mmtrya==3))
replace gaitw7=-82 if  (gaitw7==-99 & ((mmwlka>30 | mmwlka<0.54) & mmwlkb<0)) 
replace gaitw7=-83 if  (gaitw7==-99 & ((mmwlka>30 | mmwlka<0.54) & (mmwlkb>30 | mmwlkb<0.54))) 

replace gaitw7=4.877/(mmwlka+mmwlkb) if  (gaitw7==-99 & (mmwlka<30 & mmwlka>0.54) & (mmwlkb<30 & mmwlkb>0.54))
replace gaitw7 = 2.4384/mmwlka if  (gaitw7==-99 & mmwlka<30 & mmwlka>0.54) 
replace gaitw7 = 2.4384/mmwlkb if  (gaitw7==-99 & mmwlkb<30 & mmwlkb>0.54) 



gen speedindw7 = -1
replace speedindw7 = 1 if  (gaitw7>0  & (mmwlka<30 & mmwlka>0.54) )
replace speedindw7 = 2 if  (gaitw7>0 & (mmwlkb<30 & mmwlkb>0.54) )
replace speedindw7 = 3 if  (gaitw7>0 & (mmwlka<30 & mmwlka>0.54) & (mmwlkb<30 & mmwlkb>0.54))

tab speedindw7

sum gaitw7

gen gaitmisw7=gaitw7 if gaitw7<0
tab gaitmisw7

lab var  gaitw7 "Final wave1 gaitspeed (m/sec)"
lab var speedindw7 "walks used to derive gaitspeed"


lab val gaitw7 gaitlab 
lab val speedindw7 speedlab
lab val gaitmisw7 gaitlab 

tab gaitw7 if gaitw7<0



	
/********************************/
/****  PHYSICAL FUNCTIONING  ****/
/********************************/
	
	/* ADL COUNT */
sum headldr headlwa headlba headlea headlbe headlwc
tab headldr, nolab
gen adlcntw7=headldr+ headlwa+ headlba +headlea+ headlbe +headlwc
tab adlcntw7
replace adlcntw7=. if adlcntw7<0

	/* IADL COUNT */
sum headlma headlpr headlsh headlph headlme headlho headlmo
tab headlma
gen iadlcntw7=headlma +headlpr+ headlsh+ headlph+ headlme+ headlho +headlmo
tab iadlcntw7
replace iadlcntw7=. if iadlcntw7<0

	/* DIFFICULTIES WITH MOBILITY */
sum hemobwa hemobsi hemobch hemobcs hemobcl hemobst hemobre hemobpu hemobli hemobpi hemob96
tab hemobwa
gen mobilw7=hemobwa +hemobsi+ hemobch+ hemobcs +hemobcl+ hemobst+ hemobre+ hemobpu+ hemobli+ hemobpi 
tab mobilw7
replace mobilw7=. if mobilw7<0
tab mobilw7 hemob96


/*************************************/
/****  DEPRESSIVE SYMPTOMS CES-D  ****/
/*************************************/

tab	PScedA, nolab
tab PScedB
tab PScedC
tab PScedD
tab PScedE
tab PScedF, nolab
tab PScedG
tab PScedH

recode	PScedA	2=0 -9/-1=.
recode	PScedB	2=0 -9/-1=.
recode PScedC	2=0 -9/-1=.
recode PScedD 2=1 1=0 -9/-1=. /* this item is reverse coded */
recode PScedE 2=0 -9/-1=.
recode PScedF 2=1 1=0 -9/-1=. /* this item is reverse coded */
recode	PScedG	2=0 -9/-1=.
recode	PScedH	2=0 -9/-1=.




gen totcesdw7=PScedA +PScedB +PScedC+ PScedD+PScedE +PScedF +PScedG +PScedH
tab totcesdw7

gen depcesdw7=0
replace depcesdw7=1 if totcesdw7>=4
tab depcesdw7

/*************************************/
/****  QUALITY OF LIFE CASP  ****/
/*************************************/
sum scqola scqolb scqolc scqold scqole scqolf scqolg scqolh scqoli scqolj scqolk scqoll scqolm scqoln scqolo scqolp scqolq scqolr scqols

gen scqolarc=scqola 
recode scqolarc  (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolbrc=scqolb
recode scqolbrc(1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolfrc=scqolf 
recode scqolfrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolirc=scqoli
recode scqolfrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqoldrc=scqold 
recode scqoldrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)
gen scqolhrc=scqolh
recode scqolhrc (1=0)  (2=1)  (3=2)  (4=3) (-9/-1=.)

gen scqolcrc=  scqolc 
recode scqolcrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolcrc (1=0)  (2=1)  (3=2)  (4=3) 

gen scqolerc = scqole
recode scqolerc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolerc (1=0)  (2=1)  (3=2)  (4=3) 

gen scqolgrc = scqolg
recode scqolgrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolgrc (1=0)  (2=1)  (3=2)  (4=3) 

gen scqoljrc  =scqolj
recode scqoljrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqoljrc (1=0)  (2=1)  (3=2)  (4=3) 


gen scqolkrc= scqolk  
recode scqolkrc(1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolkrc (1=0)  (2=1)  (3=2)  (4=3)


gen scqollrc= scqoll 
recode scqollrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqollrc (1=0)  (2=1)  (3=2)  (4=3)


gen scqolmrc=scqolm 
recode scqolmrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolmrc (1=0)  (2=1)  (3=2)  (4=3)

gen  scqolnrc=scqoln  
recode scqolnrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolnrc (1=0)  (2=1)  (3=2)  (4=3)

gen  scqolorc= scqolo 
recode scqolorc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolorc (1=0)  (2=1)  (3=2)  (4=3)


gen  scqolprc =scqolp 
recode scqolprc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolprc (1=0)  (2=1)  (3=2)  (4=3)

gen  scqolqrc = scqolq
recode scqolqrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
recode scqolqrc (1=0)  (2=1)  (3=2)  (4=3)

 gen scqolrrc =scqolr 
 recode scqolrrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
  recode scqolrrc (1=0)  (2=1)  (3=2)  (4=3)
 
 gen scqolsrc = scqols
 recode scqolsrc (1=4)  (2=3)  (3=2)  (4=1) (-9/-1=.)
  recode scqolsrc (1=0)  (2=1)  (3=2)  (4=3)
          

gen casp19w7 =scqolarc+ scqolbrc+scqolcrc+ scqoldrc + scqolerc+scqolfrc+ scqolgrc+scqolhrc+ scqolirc+scqoljrc+  scqolkrc + scqollrc + scqolmrc+  scqolnrc + scqolorc + scqolprc + scqolqrc + scqolrrc + scqolsrc 

/****	LIMITING LONG 
		STANDING ILLNESS	 ****/
/********************************/
tab Heill
tab Helim
gen limitw7=0
replace limitw7=1 if Heill==1 & Helim==1
replace limitw7=. if Heill<0 
lab var  limitw7 "limiting longstanding illness"
lab val limitw7 nylab
tab limitw7




/*************************************/
		/* COGNITIVE FUNCTION */
/*************************************/

**CREATING MEMORY INDEX .
***NB  cflisen and cflisd MUST have -8 coded to 0 in data.

*** Maximum score = 20
tab CfLisEn
tab CfLisD 
recode CfLisEn  -9/-1=.
recode  CfLisD -9/-1=.

gen cfmew7 = CfLisEn + CfLisD  
label var cfmew7 "Memory Index"
tab cfmew7


***CREATING EXECUTIVE FUNCTION INDEX 
***creating new variable cfanig to give scores 1-9
*d/k coded to 0*

tab CfAni
recode   CfAni   0=0  -9/-1=.  1/7=1  8/12=2  13/15=3  16/17=4  18/19=5  20/21=6  22/24=7  25/29=8  30/99=9 , generate(cfanigw7)
label var  cfanigw7 "fluency recoded for executive function index"
label define cfanig  0 "0 animals" 1 "1-7 animals"   2 "8-12 animals"   3 "13-15 animals"   4 "16-17 animals"   5 "18-19 animals"   6 "20-21 animals"   7 "22-24 animals"   8 "25-29 animals"   9 "30+ animals"  
label val cfanigw7 cfanig
tab cfanigw7 cfanig
tab cfanigw7 

/* Fruit and veg */
gen fruvegw7=scveg+scfru /* portions of fruit and veg/day*/
gen por5fruvegw7 =.
replace por5fruvegw7 = 1 if fruvegw7>=5 
replace por5fruvegw7=0 if fruvegw7>=0 & fruvegw7<5

label var por5fruvegw7 "At least 5 fruit and vegetables / day"
tab por5fruvegw7




/* 3. MERGE WITH FINANCIAL DERIVED VARIABLES */
merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\Wave_7_financial_derived_variables.dta", ///
keepusing(nettotw_bu_s totinc_bu_s totinc_bu_s totwq5_bu_s yq5_bu_s)
drop if _merge==2 
drop _merge

merge 1:1 idauniq using "N:\STATS\ELSA\STATA\DATA\Wave_7_IFS_derived_variables.dta", keepusing(edqual)
drop _merge
rename edqual edqualw7
*regroup educational categories 
*Education variable - 5 category


gen edu5w7=edqualw7
recode edu5w7 1=1  2/3=2   4=3  5/6=4    7=5   -9=. -8=. -3=. -1=. -2=.
lab define edu5w7 1 "Degree or equivalent" 2 "A-lev/Higher educa. below degree " 3 "O level or other"  4 "CSE/other" 5 "No qualifications" 
lab var edu5w7 "5-group educational category"
lab val edu5w7 edu5w7
tab edu5w7
compress

*Education variable - 3 category
gen edu3w7=edqualw7
recode edu3w7 1=1  2/6=2    7=3   -9=. -8=. -3=. -1=. -2=.
lab define edu3w7  1 "Degree" 2 "Intermediate" 3 "No qualifications" 
lab var edu3w7 "3-group educational category"
lab val edu3w7 edu3w7
tab edu3w7






rename (HeEye Heeyea Hefrnd Hepap heopcdi heopfgl heopfdi heopfmd heopfca heopndi heopsdi heoptgl heoptdi heoptmd heoptca HeOpt96 hedreyr   ) =w7




keep idauniq finstatw7 hedawanw7 hedawmiw7 hedimanw7 hedimmiw7 chdw7 diabetesw7 depressw7 respiratw7 strokew7 cancerw7 ///
arthritisw7 arthw7 pa5levelw7 w7pacomb1 w7pased1 w7pased2 cigstw7 eversmkw7 limitw7 por5fruvegw7 painactw7 ///
alcohw7 maritalw7 iintdatm iintdaty indsex indager cfmew7 cfanigw7 edu5w7 edu3w7 ///
livpartw7 gaitw7 retiredw7  adlcntw7 iadlcntw7 mobilw7 totcesdw7 depcesdw7 casp19w7 ///
nettotw_bu_s totinc_bu_s totinc_bu_s totwq5_bu_s yq5_bu_s hedawbp hediabp hedimbp ///
HeEyew7 Heeyeaw7 Hefrndw7 Hepapw7 heopcdiw7 heopfglw7 heopfdiw7 heopfmdw7 heopfcaw7 heopndiw7 heopsdiw7 heoptglw7 heoptdiw7 heoptmdw7 heoptcaw7 HeOpt96w7 hedreyrw7    ///
HeFla HeFlb HeFlc  PScedC Hehelf HeLWk HeHear  NSSEC w7lwgt w7xwgt w7scwt ///
scfeela scfeelb scfeelc scfeeld scfeele scorg09 scchdj scfamj scfrdj ///
scchdg scchdh scchdi scfamg scfamh scfami scfrdg scfrdh scfrdi sclifec PScedF scptrg scchdm scfaml scfrdl

rename (indsex indager iintdatm iintdaty nettotw_bu_s totinc_bu_s totwq5_bu_s yq5_bu_s NSSEC ///
scfeela scfeelb scfeelc scfeeld scfeele scorg09 scchdj scfamj scfrdj ///
HeFla HeFlb HeFlc PScedC Hehelf HeLWk HeHear  hedawbp hediabp hedimbp ///
scchdg scchdh scchdi scfamg scfamh scfami scfrdg scfrdh scfrdi sclifec PScedF scptrg scchdm scfaml scfrdl) =w7

 /* Self-rated health*/
recode Hehelfw7 -9/-1=. 1=1 2=2 3=3 4=4 5=5
tab Hehelfw7
rename Hehelfw7 srh7
tab srh7 

recode srh7 1/3=0 4/5=1, generate (srh27)
lab var  srh27 "Fair or poor self-rated health"
lab val srh27 srh
tab srh27
keep if finstatw7 !=.
save "N:\STATS\ELSA\STATA\DATA\wave7_derived.dta", replace
 
use "N:\STATS\ELSA\STATA\DATA\wave7_derived.dta",
